package com.unis.financial.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizFinancialBudgetFillingVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialBudgetFillingFeign
 * @date 2019/8/8 18:05
 */
@FeignClient(name = "financial-server")
@Component
@Api(value = "财务预算填报", tags = "财务预算填报")
public interface FinancialBudgetFillingFeign {
    //========================================财务预算填报开始============================================================
    /**
     * 预算填报项目 根据id查询
     * @param :BizFinancialBudgetFillingVO
     * @return
     */
    @ApiOperation(value = "根据id查询预算填报项目", notes = "BizFinancialBudgetFillingVO")
    @GetMapping("/financialBudgetFilling/")
    public ResponseWrapper findInfoById(@RequestParam("id") String id);

    /**
     * 保存 预算填报项目
     * @param :BizFinancialBudgetFillingVO
     * @return
     */
    @ApiOperation(value = "保存 预算填报项目", notes = "参数：预算填报项目")
    @PostMapping(value = "/financialBudgetFilling/")
    public ResponseWrapper save(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO);


    @ApiOperation(value = "分页查找 预算填报项目", notes = "参数：预算填报项目")
    @PostMapping(value = "/financialBudgetFilling/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    );

    /**
     * @Description: 删除预算填报项目
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算填报项目", notes = "参数：预算填报项目id")
    @DeleteMapping(value = "/financialBudgetFilling/")
    public ResponseWrapper delete(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO);

    /**
     * 修改预算填报项目
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "修改预算填报项目", notes = "参数：BizFinancialBudgetFillingVO")
    @PostMapping(value = "/financialBudgetFilling/modify")
    public ResponseWrapper update(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO);

    /**
     * 预算填报项目  提交申请
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算填报项目提交申请", notes = "参数：预算填报项目提交申请")
    @PostMapping(value = "/financialBudgetFilling/application")
    public ResponseWrapper applicationSub(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO);
//==============================================预算填报项目审核start============================================================

    /**
     * 预算填报项目  审核
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算填报项目审核", notes = "参数：预算填报项目审核")
    @PostMapping(value = "/financialBudgetFilling/audit")
    public ResponseWrapper audit(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO);
    /**
     *
     * @param :BizFinancialBudgetFillingVO
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/financialBudgetFilling/findByPageOfAudit/{page}/{size}")
    public ResponseWrapper findByPageOfAudit(
            @RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    );
//==============================================预算填报项目审核end============================================================
    /**
     * @Description: 删除预算附件
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算附件", notes = "参数：填报对象id")
    @DeleteMapping(value = "/financialBudgetFilling/attachId")
    public ResponseWrapper deleteAttach(@RequestParam(value = "id",required=false) String id);
    //========================================财务预算填报结束============================================================

    
    
    /**
	 * @Description 移动端-项目年度汇总 
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "移动端-项目年度汇总  ", notes = "参数")
	@GetMapping(value = "/financialBudgetFilling/budgetSummary/{years}")
	public ResponseWrapper budgetSummary(@PathVariable("years") String years);
}
