package com.unis.financial.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizFinancialPresentationVO;
import io.swagger.annotations.Api;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialFeign
 * @date 2019/8/7 18:05
 */
@FeignClient(name = "financial-server")
@Component
@Api(value = "财务数据提报", tags = "财务数据提报")
public interface FinancialDataPresentationFeign {

//========================================财务数据提报开始============================================================
    /**
     * 企业新增财务数据
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/financialDataPresentation/")
    public ResponseWrapper saveFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO);

    /**
     * 企业删除财务数据
     * @return
     * @throws Exception
     */
    @DeleteMapping(value = "/financialDataPresentation/")
    public ResponseWrapper deleteFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO);

    /**
     * 企业财务数据修改
     * @return
     * @throws Exception
     */
    @PutMapping(value = "/financialDataPresentation/")
    public ResponseWrapper updateFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO);

    /**
     * 企业财务数据详情
     * @return
     * @throws Exception
     */
    @GetMapping(value = "/financialDataPresentation/")
    public ResponseWrapper getFinancialDate(@RequestParam("id") String id,@RequestParam("enterpriseCategory") String enterpriseCategory);

    /**
     * 企业财务数据上报
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/financialDataPresentation/financialData/")
    public ResponseWrapper subFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO);

    /**
     * 企业财务数据上报分页
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/financialDataPresentation/financialDataPage/")
    public ResponseWrapper getFinancialDataByPage(@RequestParam(required = false) String establishmentUnit,
                                                  @RequestParam(required = false) String reportYear,
                                                  @RequestParam(required = false) String reportMonth,
                                                  @RequestParam(required = false) String orgId,
    		@RequestParam("page") Integer page,
    		@RequestParam("size") Integer size);

    /**
     *功能描述  汇总数据下钻
     * @author wangqiang
     * @date 2019/9/17 0017
     * @param :[reportYear, reportMonth]
     * @return com.unis.common.utils.ResponseWrapper
     */
    @GetMapping(value = "/financialDataPresentation/drill")
    public ResponseWrapper getDrillDate(@RequestParam("reportYear") String reportYear,@RequestParam("reportMonth") String reportMonth);

    /**
     * 企业财务数据汇总分页
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/financialDataPresentation/sumDataPage/{page}/{size}")
    public ResponseWrapper getSumDataByPage(@RequestParam("reportYear") String reportYear,@RequestParam("reportMonth") String reportMonth,
                                            @PathVariable("page") Integer page,
                                            @PathVariable("size") Integer size);
    //========================================财务数据提报结束============================================================
}
