package com.unis.financial.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizPerformanceManagementVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialPerformanceManagementFeign
 * @date 2019/8/8 18:05
 */
@FeignClient(name = "financial-server")
@Component
@Api(value = "财务绩效管理", tags = "财务绩效管理")
public interface FinancialPerformanceManagementFeign {
    //========================================财务绩效管理开始============================================================
    /**
     * 预算绩效管理 根据id查询
     * @param id
     * @return
     */
    @ApiOperation(value = "根据id查询预算绩效管理", notes = "绩效id")
    @GetMapping("/financialPerformanceManagement/")
    public ResponseWrapper findPerformanceInfoById(@RequestParam("id") String id);


    @ApiOperation(value = "分页查找 预算绩效管理", notes = "参数：预算绩效管理")
    //@PostMapping(value = "/")
    @PostMapping(value = "/financialPerformanceManagement/findPerformanceByPage/{page}/{size}")
    public ResponseWrapper findPerformanceByPage(
            @RequestBody BizPerformanceManagementVO bizPerformanceManagementVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    );

    @ApiOperation(value = "保存 预算绩效管理", notes = "参数：预算绩效管理")
    @PostMapping(value = "/financialPerformanceManagement/performance")
    public ResponseWrapper savePerformance(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO) ;

    /**
     * @Description: 删除预算绩效管理
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算绩效管理", notes = "参数：预算绩效管理id")
    @DeleteMapping(value = "/financialPerformanceManagement/")
    public ResponseWrapper deletePerformance(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO);
    /**
     * 修改预算绩效管理
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "修改预算绩效管理", notes = "参数：bizPerformanceManagementVO")
    @PostMapping(value = "/financialPerformanceManagement/modifyPerformance")
    public ResponseWrapper updatePerformance(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO);
    /**
     * 预算绩效管理  提交申请
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算绩效管理提交申请", notes = "参数：预算绩效管理提交申请")
    @PostMapping(value = "/financialPerformanceManagement/applicationPerformance")
    public ResponseWrapper applicationSubPerformance(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO);
    /**
     * 预算绩效管理 根据id查询
     * @param bizPerformanceManagementVO
     * @return
     */
    @ApiOperation(value = "根据Project_id查询预算绩效管理", notes = "bizPerformanceManagementVO")
    @PostMapping("/financialPerformanceManagement/infoProjectId")
    public ResponseWrapper findInfoByProjectId(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO);

    //==============================================预算绩效管理审核start============================================================
    /**
     * 预算绩效管理  审核
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算绩效管理审核", notes = "参数：预算绩效管理审核")
    @PostMapping(value = "/financialPerformanceManagement/auditPerformance")
    public ResponseWrapper auditPerformance (@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO);

    /**
     *绩效审核分页查找
     * @param bizPerformanceManagementVO
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/financialPerformanceManagement/findByPageOfAuditPerformance/{page}/{size}")
    public ResponseWrapper findByPageOfAuditPerformance(
            @RequestBody BizPerformanceManagementVO bizPerformanceManagementVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    );
//==============================================预算绩效管理审核end============================================================

    //========================================财务绩效管理结束============================================================

}
