package com.unis.financial.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizFinancialBudgetFillingVO;
import com.unis.financial.server.service.FinancialBudgetFillingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName FinancialController
 * @Description controller
 * @Author wq
 **/

/**
 * @Api：用在请求的类上，表示对类的说明
 *     tags="说明该类的作用，可以在UI界面上看到的注解"
 *     value="该参数没什么意义，在UI界面上也看到，所以不需要配置"
 */
@RestController
@Slf4j
@Api(tags = "FinancialBudgetFillingController")
@RequestMapping("/financialBudgetFilling")
public class FinancialBudgetFillingController {

    @Autowired
    private FinancialBudgetFillingService financialBudgetFillingService;
    /**
     *@ApiOperation：用在请求的方法上，说明方法的用途、作用
     *     value="说明方法的用途、作用"
     *     notes="方法的备注说明"
     *
     * @ApiImplicitParams：用在请求的方法上，表示一组参数说明
     *     @ApiImplicitParam：用在@ApiImplicitParams注解中，指定一个请求参数的各个方面
     *         name：参数名
     *         value：参数的汉字说明、解释
     *         required：参数是否必须传
     *         paramType：参数放在哪个地方
     *             · header --> 请求参数的获取：@RequestHeader
     *             · query --> 请求参数的获取：@RequestParam
     *             · path（用于restful接口）--> 请求参数的获取：@PathVariable
     *             · body（不常用）
     *             · form（不常用）
     *         dataType：参数类型，默认String，其它值dataType="Integer"
     *         defaultValue：参数的默认值
     *
     */
    /**
     * 示例：
     * @ApiOperation(value = "select1请求",notes = "多个参数，多种的查询参数类型")
     *@ApiImplicitParams({
     *     @ApiImplicitParam(name="mobile",value="手机号",required=true,paramType="form"),
     *     @ApiImplicitParam(name="password",value="密码",required=true,paramType="form"),
     *     @ApiImplicitParam(name="age",value="年龄",required=true,paramType="form",dataType="Integer")
     * })
     */

    /**
     * 预算填报项目 根据id查询
     * @param bizFinancialBudgetFillingVO
     * @return
     */
    @ApiOperation(value = "根据id查询预算填报项目", notes = "bizFinancialBudgetFillingVO")
    @GetMapping("/")
    public ResponseWrapper findInfoById(@RequestParam("id") String id) throws Exception {
            BizFinancialBudgetFillingVO info = null;
            if(StringUtils.isNotEmpty(id)) {
                info = financialBudgetFillingService.findInfoById(id);
            }
            return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                info);
       
    }

    /**
     * 保存 预算填报项目
     * @param bizFinancialBudgetFillingVO
     * @return
     */
    @ApiOperation(value = "保存 预算填报项目", notes = "参数：预算填报项目")
    @PostMapping(value = "/")
    public ResponseWrapper save(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
        try {
            bizFinancialBudgetFillingVO = financialBudgetFillingService.saveBizFinancialBudgetFilling(bizFinancialBudgetFillingVO);
            if (bizFinancialBudgetFillingVO==null) {
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功", bizFinancialBudgetFillingVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存预算填报项目，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        
    }


    @ApiOperation(value = "分页查找 预算填报项目", notes = "参数：预算填报项目")
    //@PostMapping(value = "/")
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = financialBudgetFillingService.findByPage(bizFinancialBudgetFillingVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {

                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "查询失败");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("预算填报项目分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "查询失败");
        }
    }

    /**
     * @Description: 删除预算填报项目
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算填报项目", notes = "参数：预算填报项目id")
    @DeleteMapping(value = "/")
    public ResponseWrapper delete(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
        try {
            Boolean flag = financialBudgetFillingService.deleteById(bizFinancialBudgetFillingVO);
            if (!flag) {
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "删除失败");
            }
            return ResponseWrapper.success(200, "删除成功", flag);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除失败");
        }
    }

    /**
     * 修改预算填报项目
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "修改预算填报项目", notes = "参数：bizFinancialBudgetFillingVO")
    @PostMapping(value = "/modify")
    public ResponseWrapper update(
            @RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO
    ) {
        //System.out.println("修改=====预算填报项目==="+bizFinancialBudgetFillingVO.toString());
        try {
            bizFinancialBudgetFillingVO = financialBudgetFillingService.update(bizFinancialBudgetFillingVO);
            if (bizFinancialBudgetFillingVO==null) {
            	 return ResponseWrapper.error(
                         HttpStatus.INTERNAL_SERVER_ERROR.value(),
                         HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                         "修改失败");
            }
            return ResponseWrapper.success(200, "修改成功",bizFinancialBudgetFillingVO);
        } catch (Exception e) {
            log.error( "预算填报项目更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "修改失败");
        }

    }

    /**
     * 预算填报项目  提交申请
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算填报项目提交申请", notes = "参数：预算填报项目提交申请")
    @PostMapping(value = "/application")
    public ResponseWrapper applicationSub(@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
        try {
            BizFinancialBudgetFillingVO result = null;
            if (StringUtils.isEmpty(bizFinancialBudgetFillingVO.getId())) {
                //先保存
                ResponseWrapper save = save(bizFinancialBudgetFillingVO);
                BizFinancialBudgetFillingVO data = (BizFinancialBudgetFillingVO) save.getData();
                result = financialBudgetFillingService.applicationSub(data);
            }else {
                result = financialBudgetFillingService.applicationSub(bizFinancialBudgetFillingVO);
            }if (ObjectUtils.notEqual(result, null)) {
                return  ResponseWrapper.success(
                        HttpStatus.OK.value(),
                        HttpStatus.OK.getReasonPhrase(),
                        result);
            }
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "已存在无法添加");
        } catch (Exception e) {
            log.error("反馈，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "已存在无法添加");
        }
    }
//==============================================预算填报项目审核============================================================
    /**
     * 预算填报项目  审核
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算填报项目审核", notes = "参数：预算填报项目审核")
    @PostMapping(value = "/audit")
    public ResponseWrapper audit (@RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) throws Exception {
            BizFinancialBudgetFillingVO result = financialBudgetFillingService.audit(bizFinancialBudgetFillingVO);
            if (ObjectUtils.notEqual(result, null)) {
                return  ResponseWrapper.success(
                        HttpStatus.OK.value(),
                        HttpStatus.OK.getReasonPhrase(),
                        null);
            }
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算项目审核失败");
    }

    /**
     *审核分页查找
     * @param bizFinancialBudgetFillingVO
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/findByPageOfAudit/{page}/{size}")
    public ResponseWrapper findByPageOfAudit(
            @RequestBody BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) throws Exception {
            PageInfo<List<Map>> result = financialBudgetFillingService.findByPageOfAudit(bizFinancialBudgetFillingVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {

                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "查询失败");
    }

    /**
     * @Description: 删除预算附件
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算附件", notes = "参数：填报对象id")
    @DeleteMapping(value = "/attachId")
    public ResponseWrapper deleteAttach(@RequestParam(value = "id",required=false) String id) {
        try {
            Boolean flag = financialBudgetFillingService.deleteAttachById(id);
            if (!flag) {
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "参数错误，删除预算附件");
            }
            return ResponseWrapper.success(200, "删除预算附件成功",flag);
            
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "参数错误，删除预算附件");
        }
    }
    
    /**
	 * @Description 移动端-项目年度汇总 
	 * @version v1.0
	 * @author lfx
	 * @param page
	 * @param size
	 * @date 2018/10/19
	 * @return com.unis.sxls.user.units.ResponseWrapper
	 * @throws 
	 */
	@ApiOperation(value = "移动端-项目年度汇总  ", notes = "参数")
	@GetMapping(value = "/budgetSummary/{years}")
	public ResponseWrapper budgetSummary(@PathVariable("years") String years) throws Exception{
		List<Map> result  = financialBudgetFillingService.budgetSummary(years);
		return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
	}
	

}
