package com.unis.financial.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizFinancialPresentationVO;
import com.unis.financial.server.entity.father.BizFinancialPresentationDO;
import com.unis.financial.server.service.FinancialDataPresentationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @ClassName FinancialController
 * @Description controller层样例模板
 * @Author tiechanglong
 * @Date 2019/7/22 17:07
 * @Version 0.0.3
 **/

/**
 * @Api：用在请求的类上，表示对类的说明
 *     tags="说明该类的作用，可以在UI界面上看到的注解"
 *     value="该参数没什么意义，在UI界面上也看到，所以不需要配置"
 */
@RestController
@Slf4j
@Api(tags = "FinancialDataPresentationController")
@RequestMapping("/financialDataPresentation")
public class FinancialDataPresentationController {

    @Autowired
    private FinancialDataPresentationService financialDataPresentationService;

    /**
     *
     * 企业财务上报数据分页
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "企业财务上报数据分页 Busi项目", notes = "参数：")
    @PostMapping(value = "/dataPage/{page}/{size}")
    public ResponseWrapper getDataByPage(@RequestParam("establishmentUnit") String establishmentUnit,
                                         @RequestParam("reportYear") String reportYear,@RequestParam("reportMonth") String reportMonth,
                                         @PathVariable("page") Integer page,
                                         @PathVariable("size") Integer size){
        try {
            PageInfo<List<Map>> result = financialDataPresentationService.getDataByPage(establishmentUnit,reportYear,reportMonth,page,size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(HttpStatus.OK.value(),HttpStatus.OK.getReasonPhrase(),result);
            }
            return ResponseWrapper.success(HttpStatus.NO_CONTENT.value(),HttpStatus.NO_CONTENT.getReasonPhrase(),result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("企业财务上报数据分页查看，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "企业财务上报数据分页查看失败");        }
    }

    /**
     *
     * 企业财务上报数据汇总分页
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "企业财务上报数据汇总分页 Busi项目", notes = "参数：")
    @PostMapping(value = "/sumDataPage/{page}/{size}")
    public ResponseWrapper countDataPage(
            @RequestParam("reportYear") String reportYear,@RequestParam("reportMonth") String reportMonth,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size){
        try {
            PageInfo<List<Map>> result = financialDataPresentationService.countDataPage(reportYear,reportMonth,page,size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(HttpStatus.OK.value(),HttpStatus.OK.getReasonPhrase(),result);
            }
            return ResponseWrapper.success(HttpStatus.NO_CONTENT.value(),HttpStatus.NO_CONTENT.getReasonPhrase(),result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("企业财务上报数据分页查看，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "企业财务上报数据分页查看失败");
        }
    }
    /**
     *功能描述  获取汇总下钻数据
     * @author wangqiang
     * @date 2019/9/17 0017
     * @param :[year month]
     * @return com.unis.common.utils.ResponseWrapper
     */
    @ApiOperation(value = "企业财务数据详情", notes = "参数：")
    @GetMapping(value = "/drill")
    public ResponseWrapper getDrillDate(@RequestParam("reportYear") String reportYear,@RequestParam("reportMonth") String reportMonth){
        Map<String,BizFinancialPresentationDO> stringListMap = financialDataPresentationService.drillData(reportYear, reportMonth);
        return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),stringListMap);
    }

    //================================================供 企业端项目调用===============================================
    /**
     * 企业新增财务数据
     * @return ResponseWrapper
     * @author wq
     * @version v1.0
     */
    @ApiOperation(value = "企业新增财务数据", notes = "参数：BizFinancialPresentationVO")
    @PostMapping(value = "/")
    public ResponseWrapper saveFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO) {
        try {
            BizFinancialPresentationVO data = financialDataPresentationService.saveFinancialDate(bizFinancialPresentationVO);
            if (ObjectUtils.notEqual(data, null)) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),data);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),data);
        } catch (Exception e) {
            log.error("企业新增财务数据，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "企业新增财务数据失败");
        }
    }

    /**
     * @Description: 企业删除财务数据
     * @return ResponseWrapper
     */
    @ApiOperation(value = "企业删除财务数据", notes = "参数：企业删除财务数据id")
    @DeleteMapping(value = "/")
    public ResponseWrapper deleteFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO) {
        try {
            Boolean flag = financialDataPresentationService.deleteFinancialDate(bizFinancialPresentationVO);
            if (!flag) {
                return ResponseWrapper.error(
                        HttpStatus.BAD_REQUEST.value(),
                        HttpStatus.BAD_REQUEST.getReasonPhrase(),
                        "删除失败");
            }
            return  ResponseWrapper.success(
                    HttpStatus.OK.value(),
                    HttpStatus.OK.getReasonPhrase(),
                    null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"删除失败");
        }
    }

    /**
     * 企业财务数据修改
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "企业财务数据修改", notes = "参数：bizFinancialPresentationVO")
    @PutMapping(value = "/")
    public ResponseWrapper updateFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO){
        try {
            //业务逻辑校验
//            String tip = businessLogicJudgment(bizFinancialPresentationVO);
//            if (StringUtils.isEmpty(tip)) {
//                return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), tip,"验证失败");
//            }
            Boolean flag = financialDataPresentationService.updateFinancialDate(bizFinancialPresentationVO);
            if (!flag) {
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
            }
            return ResponseWrapper.success(HttpStatus.OK.value(),HttpStatus.OK.getReasonPhrase(),null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("修改对象，发生异常", e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
        }
    }

    /**
     * 企业财务数据详情
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "企业财务数据详情", notes = "参数：id")
    @GetMapping(value = "/")
    public ResponseWrapper getFinancialDateByIdAndCategory(@RequestParam("id") String id,@RequestParam("enterpriseCategory") String enterpriseCategory){
            BizFinancialPresentationVO data = financialDataPresentationService.getFinancialDate(id,enterpriseCategory);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),data);
    }

    /**
     * 企业端
     * 企业财务分页数据
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "企业财务数据分页", notes = "参数：")
    @PostMapping(value = "/financialDataPage/")
    public ResponseWrapper getFinancialDataByPage(@RequestParam(required = false) String establishmentUnit,
                                                  @RequestParam(required = false) String reportYear,
                                                  @RequestParam(required = false) String reportMonth,
    		                                      @RequestParam(required = false) String orgId,
    		@RequestParam("page") Integer page,
    		@RequestParam("size") Integer size){
        try {
            PageInfo<List<Map>> result = financialDataPresentationService.getFinancialDataByPage(establishmentUnit,reportYear,reportMonth,orgId,page,size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(HttpStatus.OK.value(),HttpStatus.OK.getReasonPhrase(),result);
            }
            return ResponseWrapper.error(HttpStatus.NO_CONTENT.value(),HttpStatus.NO_CONTENT.getReasonPhrase(),"查看失败");
        }
        catch (Exception e) {
            e.printStackTrace();
            log.error("企业财务数据分页查看，发生异常", e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查看失败");
        }
    }

    /**
     * 企业财务数据上报
     * @return ResponseWrapper
     * @author wq
     * @version v1.0
     */
    @ApiOperation(value = "企业财务数据上报", notes = "参数：BizFinancialPresentationVO")
    @PostMapping(value = "/financialData")
    public ResponseWrapper subFinancialDate(@RequestBody BizFinancialPresentationVO bizFinancialPresentationVO) {
        try {
            Boolean flag= financialDataPresentationService.subFinancialDate(bizFinancialPresentationVO);
            //Boolean flag = financialDataPresentationService.updateFinancialDate(bizFinancialPresentationVO);
            if (!flag) {
                return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(),HttpStatus.BAD_REQUEST.getReasonPhrase(),"上报失败");
            }
            return ResponseWrapper.success(HttpStatus.OK.value(),HttpStatus.OK.getReasonPhrase(),null);
        } catch (Exception e) {
            log.error("企业财务数据上报，发生异常："+e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"上报失败");
        }
    }

    /**
     *  业务逻辑判断
     * @param bizFinancialPresentationVO
     * @return String
     */
    private String  businessLogicJudgment(BizFinancialPresentationVO bizFinancialPresentationVO) {
        //提示语
        String tip = "";
        //业务逻辑判断
       /* 注：判断条件，符合才能保存，否则给予提示
        1、费用总额=利息+工资和社保+保管费+运杂费+折旧费及摊销
        2、营业外收支净额=营业收入-营业成本-费用总额-营业税金及附加
        3、利润总额=营业外收支净额+其他项目收支净额
        4、政府补助=粮油补贴收入+其他补助
        5、净利润=利润总额-所得税费用
        6、流动资产>=存货+货币资金+应收及预付账款+其他应收款
        7、流动负债>=短期借款+应付及预收账款+其他应付款
        8、毛利率=（营业收入-营业成本）/营业收入
        9、资产负债率=负债总额/资产总额
        10、资产总额=负债总额+所有者权益
        11、其他金融机构贷款自己添加银行名称以及对应的贷款金额。
        12.上报周期支持手动输入，也可选择*/
        //===========1 费用总额=利息+工资和社保+保管费+运杂费+折旧费及摊销
        //费用总额
        BigDecimal totalCost = bizFinancialPresentationVO.getTotalCost();
        //利息
        //BigDecimal interest = bizFinancialPresentationVO.getInterest();
        //工资和社保
        BigDecimal wagesAndSocialSecurity = bizFinancialPresentationVO.getWagesAndSocialSecurity();
        //保管费
        BigDecimal depositCharges = bizFinancialPresentationVO.getDepositCharges();
        //运杂费
        BigDecimal freightMiscellaneousCharges = bizFinancialPresentationVO.getFreightMiscellaneousCharges();
        //折旧费及摊销
        BigDecimal depreciationAndAmortization = bizFinancialPresentationVO.getDepreciationAndAmortization();
//        if (totalCost != interest.add(wagesAndSocialSecurity).add(depositCharges).add(freightMiscellaneousCharges).add(depreciationAndAmortization)) {
//            tip = "费用总额=利息+工资和社保+保管费+运杂费+折旧费及摊销";
//            return tip;
//        }
        //===============2营业外收支净额=营业收入-营业成本-费用总额-营业税金及附加
        //营业外收支净额
        BigDecimal netOutOfBusinessIncome = bizFinancialPresentationVO.getNetOutOfBusinessIncome();
        //营业收入
        BigDecimal salesIncome = bizFinancialPresentationVO.getSalesIncome();
        //营业成本
        BigDecimal salesCost = bizFinancialPresentationVO.getSalesCost();
        //费用总额 见上(1)
        //营业税金及附加
        //BigDecimal taxesAndSurcharges = bizFinancialPresentationVO.getTaxesAndSurcharges();
//        if (netOutOfBusinessIncome.compareTo(salesIncome.subtract(salesCost).subtract(totalCost).subtract(taxesAndSurcharges)) !=0 ) {
//            tip = "营业外收支净额=营业收入-营业成本-费用总额-营业税金及附加";
//            return tip;
//        }
        //===============3利润总额=营业外收支净额+其他项目收支净额
        //利润总额
        BigDecimal totalProfit = bizFinancialPresentationVO.getTotalProfit();
        //营业外收支净额 见上(2)
        //其他项目收支净额
//        BigDecimal netRevenueOfOtherProjects = bizFinancialPresentationVO.getNetRevenueOfOtherProjects();
//        if (totalProfit.compareTo(netOutOfBusinessIncome.add(netRevenueOfOtherProjects)) != 0) {
//            tip = "利润总额=营业外收支净额+其他项目收支净额";
//            return tip;
//        }
        //===============4政府补助=粮油补贴收入+其他补助
        //政府补助
        BigDecimal governmentGrants = bizFinancialPresentationVO.getGovernmentGrants();
        //粮油补贴收入
        BigDecimal grainOilSubsidiesIncome = bizFinancialPresentationVO.getGrainOilSubsidiesIncome();
        //其他补助
        BigDecimal otherSubsidies = bizFinancialPresentationVO.getOtherSubsidies();
        if (governmentGrants.compareTo(grainOilSubsidiesIncome.add(otherSubsidies)) !=0 ) {
            tip = "政府补助=粮油补贴收入+其他补助";
            return tip;
        }
        //===============5 净利润=利润总额-所得税费用
        //净利润
        BigDecimal netProfit = bizFinancialPresentationVO.getNetProfit();
        //利润总额  见上(3)
        //所得税费用
        BigDecimal incomeTaxExpenses = bizFinancialPresentationVO.getIncomeTaxExpenses();
        if (netProfit.compareTo(totalProfit.subtract(incomeTaxExpenses)) !=0 ) {
            tip = "净利润=利润总额-所得税费用";
            return tip;
        }
        //===============6 流动资产>=存货+货币资金+应收及预付账款+其他应收款
        //流动资产
        BigDecimal currentAssets = bizFinancialPresentationVO.getCurrentAssets();
        //存货
        BigDecimal stock = bizFinancialPresentationVO.getStock();
        //货币资金
        BigDecimal monetaryFunds = bizFinancialPresentationVO.getMonetaryFunds();
        //应收及预付账款
        BigDecimal accountsReceivablePrepaid = bizFinancialPresentationVO.getAccountsReceivablePrepaid();
        //其他应收款
        BigDecimal otherReceivables = bizFinancialPresentationVO.getOtherReceivables();
        if (currentAssets.compareTo(stock.add(monetaryFunds).add(accountsReceivablePrepaid).add(otherReceivables))==-1) {
            tip = "流动资产>=存货+货币资金+应收及预付账款+其他应收款";
            return tip;
        }
        //===============7 流动负债>=短期借款+应付及预收账款+其他应付款
        //流动负债
        BigDecimal currentLiabilities = bizFinancialPresentationVO.getCurrentLiabilities();
        //短期借款
        BigDecimal shortTermBorrowing = bizFinancialPresentationVO.getShortTermBorrowing();
        //应付及预收账款
        BigDecimal accountsPayableAndPrepaid = bizFinancialPresentationVO.getAccountsPayableAndPrepaid();
        //其他应付款
        BigDecimal otherAccountsPayable = bizFinancialPresentationVO.getOtherAccountsPayable();
        if (currentLiabilities.compareTo(shortTermBorrowing.add(accountsPayableAndPrepaid).add(otherAccountsPayable))==-1) {
            tip = "流动负债>=短期借款+应付及预收账款+其他应付款";
            return tip;
        }
        //===============10 资产总额=负债总额+所有者权益
        //资产负债率
        BigDecimal ownerRightsAndInterests = bizFinancialPresentationVO.getOwnerRightsAndInterests();
        //负债总额
        BigDecimal totalLiabilities = bizFinancialPresentationVO.getTotalLiabilities();
        //资产总额
        BigDecimal totalAssets = bizFinancialPresentationVO.getTotalAssets();
        if (totalAssets.compareTo(totalLiabilities.add(ownerRightsAndInterests))!=0) {
            tip = "资产总额=负债总额+所有者权益";
            return tip;
        }
        return tip;
    }


}
