package com.unis.financial.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.common.vo.BizPerformanceManagementVO;
import com.unis.financial.server.service.FinancialBudgetFillingService;
import com.unis.financial.server.service.FinancialPerformanceManagementService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName FinancialPerformanceManagementController
 * @Description controller层样例模板
 * @Author tiechanglong
 * @Date 2019/7/22 17:07
 * @Version 0.0.3
 **/

/**
 * @Api：用在请求的类上，表示对类的说明
 *     tags="说明该类的作用，可以在UI界面上看到的注解"
 *     value="该参数没什么意义，在UI界面上也看到，所以不需要配置"
 */
@RestController
@Slf4j
@Api(tags = "FinancialPerformanceManagementController")
@RequestMapping("/financialPerformanceManagement")
public class FinancialPerformanceManagementController {

    @Autowired
    private FinancialPerformanceManagementService bizPerformanceManagementService;
    
    @Autowired
    private FinancialBudgetFillingService bizFinancialBudgetFillingService;
  //==============================================预算绩效管理============================================================
    /**
     * 预算绩效管理 根据id查询
     * @param BizPerformanceManagementVO
     * @return
     */
    @ApiOperation(value = "根据id查询预算绩效管理", notes = "BizPerformanceManagementVO")
    @GetMapping("/")
    public ResponseWrapper findPerformanceInfoById(@RequestParam("id") String id) {
        try {
            BizPerformanceManagementVO info = null;
            if(StringUtils.isNotEmpty(id)) {
                info = bizPerformanceManagementService.findInfoById(id);
            }
            return ResponseWrapper.success(200, "预算绩效管理 查找成功", info);
        } catch (Exception e) {
            log.error("查询预算绩效管理数据，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理信息查询失败");
        }
    }
    /**
     * 保存 预算绩效管理   自测时用,绩效是没有保存的,数据来源于预算填报
     * @param BizPerformanceManagementVO
     * @return
     */
    @ApiOperation(value = "保存 预算绩效管理", notes = "参数：预算绩效管理")
    @PostMapping(value = "/performance")
    public ResponseWrapper savePerformance(@RequestBody BizPerformanceManagementVO BizPerformanceManagementVO) {
        try {
            BizPerformanceManagementVO = bizPerformanceManagementService.saveBizPerformanceManagement(BizPerformanceManagementVO);
            if (BizPerformanceManagementVO == null) {
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "预算绩效管理保存失败");
            }
            return ResponseWrapper.success(200, "保存成功", BizPerformanceManagementVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存预算绩效管理，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "保存失败");
            
        }
    }

    @ApiOperation(value = "分页查找 预算绩效管理", notes = "参数：预算绩效管理")
    //@PostMapping(value = "/")
    @PostMapping(value = "/findPerformanceByPage/{page}/{size}")
    public ResponseWrapper findPerformanceByPage(
            @RequestBody BizPerformanceManagementVO BizPerformanceManagementVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizPerformanceManagementService.findByPage(BizPerformanceManagementVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {

                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error(HttpStatus.NO_CONTENT.value(),HttpStatus.NO_CONTENT.getReasonPhrase(),"数据为空");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("预算绩效管理分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理查询失败");
        }
    }

    /**
     * @Description: 删除预算绩效管理
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算绩效管理", notes = "参数：预算绩效管理id")
    @DeleteMapping(value = "/")
    public ResponseWrapper deletePerformance(@RequestBody BizPerformanceManagementVO bizPerformanceManagementVO) {
        try {
            Boolean flag = bizPerformanceManagementService.deleteById(bizPerformanceManagementVO);
            if (!flag) {
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "预算绩效管理查询失败");
            }
            return ResponseWrapper.success(
	                HttpStatus.OK.value(),
	                HttpStatus.OK.getReasonPhrase(),
	                "预算绩效管理删除成功");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理删除失败");
        }
    }

    /**
     * 修改预算绩效管理
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "修改预算绩效管理", notes = "参数：BizPerformanceManagementVO")
    @PostMapping(value = "/modifyPerformance")
    public ResponseWrapper updatePerformance(
            @RequestBody BizPerformanceManagementVO BizPerformanceManagementVO
    ) {
        //System.out.println("修改=====预算填报项目==="+bizFinancialBudgetFillingVo.toString());
        try {
            BizPerformanceManagementVO = bizPerformanceManagementService.update(BizPerformanceManagementVO);
            return ResponseWrapper.success(200, "修改成功",BizPerformanceManagementVO);
        } catch (Exception e) {
            log.error( "预算绩效管理更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理修改失败");
        }

    }

    /**
     * 预算绩效管理  提交申请
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算绩效管理提交申请", notes = "参数：预算绩效管理提交申请")
    @PostMapping(value = "/applicationPerformance")
    public ResponseWrapper applicationSubPerformance(@RequestBody BizPerformanceManagementVO BizPerformanceManagementVO) {
        try {
            BizPerformanceManagementVO result = bizPerformanceManagementService.applicationSub(BizPerformanceManagementVO);
            if (result == null){
                return ResponseWrapper.error(
                        HttpStatus.INTERNAL_SERVER_ERROR.value(),
                        HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                        "预算绩效管理提交失败");
            }
            return ResponseWrapper.success(200, "预算绩效管理提交成功", result);
        } catch (Exception e) {
            log.error("反馈，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理提交失败");
            
        }
    }


    /**
     * 预算绩效管理 根据id查询
     * @param BizPerformanceManagementVO
     * @return
     */
    @ApiOperation(value = "根据Project_id查询预算绩效管理", notes = "BizPerformanceManagementVO")
    @PostMapping("/infoProjectId")
    public ResponseWrapper findInfoByProjectId(@RequestBody BizPerformanceManagementVO BizPerformanceManagementVO) {
        try {
            List<BizPerformanceManagementVO> infoByProjectIdList = null;
            if(StringUtils.isNotEmpty(BizPerformanceManagementVO.getId())) {
                infoByProjectIdList = bizPerformanceManagementService.findInfoByProjectId(BizPerformanceManagementVO);
            }
            return ResponseWrapper.success(200, "查找成功", infoByProjectIdList);
        } catch (Exception e) {
            log.error("查询预算绩效管理数据，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理信息查询失败");
            // return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"预算绩效管理信息查询失败");
        }
    }

    //==============================================预算绩效管理审核============================================================
    /**
     * 预算绩效管理  审核
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预算绩效管理审核", notes = "参数：预算绩效管理审核")
    @PostMapping(value = "/auditPerformance")
    public ResponseWrapper auditPerformance (@RequestBody BizPerformanceManagementVO BizPerformanceManagementVO){
        try {
            BizPerformanceManagementVO result = bizPerformanceManagementService.audit(BizPerformanceManagementVO);

                return ResponseWrapper.success(200, "提交成功",true);

        } catch (Exception e) {
            log.error("预算绩效管理审核，发生异常："+e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理提交失败");
        }
    }

    /**
     *
     * @param BizPerformanceManagementVO
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/findByPageOfAuditPerformance/{page}/{size}")
    public ResponseWrapper findByPageOfAuditPerformance(
            @RequestBody BizPerformanceManagementVO BizPerformanceManagementVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            PageInfo<List<Map>> result = bizPerformanceManagementService.findByPageOfAudit(BizPerformanceManagementVO, page, size);
            return ResponseWrapper.success(200, "查询成功", result);

        } catch (Exception e) {
            e.printStackTrace();
            log.error("预算绩效管理分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "预算绩效管理查询失败");
        }
    }

    /**
     * @Description: 删除预算附件
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除预算附件", notes = "参数：填报对象id")
    @DeleteMapping(value = "/attachId")
    public ResponseWrapper deleteAttach(@RequestParam(value = "id",required=false) String id) {
        try {
            Boolean flag = bizFinancialBudgetFillingService.deleteAttachById(id);
            if (!flag) {
                return ResponseWrapper.error(300, "参数错误，删除预算附件",null);
            }
            return ResponseWrapper.success(200, "删除预算附件成功",flag);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "删除预算附件失败",null);
        }
    }

}
