package com.unis.financial.server.controller;

import java.awt.image.BufferedImage;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.ResponseWrapper;
import com.unis.financial.server.entity.father.SysCwModelsDO;
import com.unis.financial.server.service.SysCwModelsService;
import com.unis.financial.server.utils.ImageUtils;
import com.unis.financial.server.utils.PageHelperUtils;
import com.unis.financial.server.utils.WordUtil;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(tags = "部门预算管理")
@RequestMapping("/sysCwModels")
public class SysCwModelsController {

	@Resource
	private SysCwModelsService sysCwModelsService;

	@ApiOperation(value = "查找财务模板数据", notes = "支持分页")
	@RequestMapping(value = "/getList/{page}/{size}", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    public ResponseWrapper getList(@PathVariable("page") Integer page, @PathVariable("size") Integer size, 
    		@RequestParam(value="dataType", required=false) String dataType, 
    		@RequestParam(value="orgCode", required=false) String orgCode, 
    		@RequestParam(value="depotCode", required=false) String depotCode,
    		@RequestParam(value="tbnf", required=false) String tbnf) {
		JSONObject json = null;
		try {
			List<SysCwModelsDO> list = sysCwModelsService.findByList(dataType, orgCode, depotCode, tbnf, null);
			//处理分页数据
			String datas = PageHelperUtils.pageHelper(new ObjectMapper().writeValueAsString(list).toString(), page, size);
			json = JSONObject.parseObject(datas);
		} catch (Exception e) {
			log.error("查找财务模板数据查询失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "查询失败");
		}
		return ResponseWrapper.success(200, "查询成功", json);
	}

	@ApiOperation(value = "查找一条财务模板数据", notes = "")
	@RequestMapping(value = "/findByParmary", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    public ResponseWrapper findByParmary(@RequestParam(value="id", required=true) String id) {
		SysCwModelsDO sysCwModelsDO = null;
		try {
			sysCwModelsDO = sysCwModelsService.findByParmary(id);
		} catch (Exception e) {
			log.error("查找财务模板数据查询失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "查询失败");
		}
		return ResponseWrapper.success(200, "财务模板数据查询成功", sysCwModelsDO);
	}

	@ApiOperation(value = "修改或新增一条财务模板数据", notes = "")
	@RequestMapping(value = "/saveOrUpdate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    public ResponseWrapper saveOrUpdate(@RequestBody SysCwModelsDO sysCwModelsDO, @RequestParam(value="operateName", required=true) String operateName) {
		try {
			//校验当前数据是否已经有相同年份的数据
			PageHelper.clearPage();
			List<SysCwModelsDO> list = sysCwModelsService.findByList(sysCwModelsDO.getDataType(), null, sysCwModelsDO.getDepotCode(), sysCwModelsDO.getTbnf(), sysCwModelsDO.getId());
			if (null != list && list.size() > 0) {
				return ResponseWrapper.success(900, "当前数据所属部门已填报过"+sysCwModelsDO.getTbnf()+"年的数据，不可重复上报", sysCwModelsDO);
			} else {
				sysCwModelsService.updateOrSave(sysCwModelsDO, operateName);
				return ResponseWrapper.success(200, "财务模板数据保存成功", sysCwModelsDO);
			}
		} catch (Exception e) {
			log.error("财务模板数据保存失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "财务模板数据保存失败");
		}
	}

	@ApiOperation(value = "删除一条财务模板数据", notes = "")
	@RequestMapping(value = "/removeSysCwModels", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    public ResponseWrapper removeSysCwModels(@RequestParam(value="id", required=true)String id) {
		try {
			sysCwModelsService.deleteSysCwModels(id);
		} catch (Exception e) {
			log.error("删除一条财务模板数据失败{}", e.getMessage());
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "操作失败");
		}
		return ResponseWrapper.success(200, "删除一条财务模板数据成功", id);
	}

	@ApiOperation(value = "导出文本到Word", notes = "支持图片,但需要把图片转成base64编码")
	@RequestMapping(value = "/exportWord", method=RequestMethod.POST)
    public void export(HttpServletRequest request, HttpServletResponse response, @RequestParam(value="id", required=true)String id) throws Exception {
        try {
//            String tmpContent = "<h1>如何将富文本内容导出到word文档</h1><p style=\"color:red;font-size:20px;\">采用poi将富文本内容导出到word文档</p><div style=\"background-color:green;\">这是有背景颜色的div内容</div>\n" +
//                    "<img src=\"这里写base64后的图片编码\">这是base64编码后的图片";
        	SysCwModelsDO sysCwModelsDO = sysCwModelsService.findByParmary(id);
        	String tmpContent = "";
        	String modelName = "";
        	if (null != sysCwModelsDO) {
        		tmpContent = sysCwModelsDO.getMText();
        		modelName = sysCwModelsDO.getMName();
        	}
 
            // 获取img图片标签
            // 1.Jsoup解析html
            Document document = Jsoup.parse(tmpContent);
            // 获取所有img图片标签
            Elements img = document.getElementsByTag("img");
            int index = 0;
            List<String> imgBase64List = new ArrayList<>();
            for (Element element : img) {
                imgBase64List.add(element.attr("src"));
                // 处理特殊符号
                String attrData = element.attr("src");
                // base64编码后可能包含 + 特殊字符,所以需要转义
                attrData = attrData.replaceAll("\\+", "\\\\+");
                tmpContent = tmpContent.replaceAll(attrData, "{{image_src" + index + "}}");
                index++;
            }
            // 缩放图片大小,然后重新base64编码后替换到富文本内容里面导出word
            index = 0;
            String prefix = "data:image/png;base64,"; // base64编码前缀
            for (String base64 : imgBase64List) {
                if (StringUtils.isNotBlank(base64)) {
                    // 缩小图片
                    base64 = base64.replaceAll(prefix, "");
                    BufferedImage bufferedImage = ImageUtils.bytesToBufferedImage(ImageUtils.base64ToByte(base64));
                    if (bufferedImage == null) {
                        tmpContent = tmpContent.replaceAll("\\{\\{image_src" + index + "}}", "");
                    } else {
                        int height = bufferedImage.getHeight();
                        int width = bufferedImage.getWidth();
                        // 如果图片宽度大于650,图片缩放
                        //System.out.println("----"+width+"-----"+height);
                        if (width > 650) {
                            //高度等比缩放
                            height = (int)(height*650.0/width);
                            BufferedImage imgZoom = ImageUtils.resizeImage(bufferedImage, 700, height);
                            String imageToBase64 = ImageUtils.imageToBase64(ImageUtils.imageToBytes(imgZoom));
                            tmpContent = tmpContent.replaceAll("\\{\\{image_src" + index + "}}", prefix + imageToBase64);
                        } else {
                            tmpContent = tmpContent.replaceAll("\\{\\{image_src" + index + "}}", prefix + base64);
                        }
                    }
                } else {
                    tmpContent = tmpContent.replaceAll("\\{\\{image_src" + index + "}}", "");
                }
                index++;
            }
            // 执行导出操作
            WordUtil.exportHtmlToWord(request, response, tmpContent, modelName);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
