package com.unis.financial.server.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.common.utils.ObjectUtils;
import com.unis.financial.common.vo.BizFinancialBudgetFillingVO;
import com.unis.financial.common.vo.OutPutIndexQueryVO;
import com.unis.financial.common.vo.OverallObjectiveVO;
import com.unis.financial.server.dao.BenefitIndexDao;
import com.unis.financial.server.dao.FinancialBudgetFillingDao;
import com.unis.financial.server.dao.FinancialBusinessProjectDao;
import com.unis.financial.server.dao.OutPutIndexDao;
import com.unis.financial.server.dao.OverallObjectiveDao;
import com.unis.financial.server.dao.SatisfactionIndexDao;
import com.unis.financial.server.entity.father.BenefitIndexDO;
import com.unis.financial.server.entity.father.BizFinancialBudgetFillingDO;
import com.unis.financial.server.entity.father.BusinessProjectDO;
import com.unis.financial.server.entity.father.OutPutIndexDO;
import com.unis.financial.server.entity.father.OverallObjectiveDO;
import com.unis.financial.server.entity.father.SatisfactionIndexDO;
import com.unis.financial.server.enums.ApprovalTypeEnum;
import com.unis.financial.server.service.FinancialBudgetFillingService;

import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialBudgetFillingServiceImpl
 * @ProjectName FinancialBudgetFillingServiceImpl
 * @Description: 应急台账的业务层
 * @date
 */
@Service
public class FinancialBudgetFillingServiceImpl implements FinancialBudgetFillingService {

	//@Autowired
	//private FinancialDomain financialDomain;
	@Autowired
	private FinancialBudgetFillingDao financialBudgetFillingDao;
	@Autowired
	private FinancialBusinessProjectDao financialBusinessProjectDao;

	@Autowired
	private OutPutIndexDao outPutIndexDao;
	
	@Autowired
	private BenefitIndexDao benefitIndexDao;

	@Autowired
	private SatisfactionIndexDao satisfactionIndexDao;
	
	@Autowired
	private OverallObjectiveDao overallObjectiveDao;
	
	  //判断字符串是否为空
    public String isNull(String key) {
    	String str="";
    	if("null".equals(key)) {
    		str="";
    	}else {
    		str=key;
    	}
    	return  str;
    }
	/**
	 * 预算填报项目-->申请  保存
	 * @param bizFinancialBudgetFillingVO
	 * @return
	 */
	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizFinancialBudgetFillingVO saveBizFinancialBudgetFilling(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		try {
			//保存项目填报相关信息
			bizFinancialBudgetFillingVO.setCreateTime(new Date());
			bizFinancialBudgetFillingVO.setDeleteBy("-1");
			bizFinancialBudgetFillingVO.setDeleteTime(null);


			//初始状态未提交
			bizFinancialBudgetFillingVO.setId(UUIDUtils.uuid());

			//保存项目表
			
			BusinessProjectDO businessProjectDO = new BusinessProjectDO();
			businessProjectDO.setCreateBy(bizFinancialBudgetFillingVO.getCreateBy());
			businessProjectDO.setCreateTime(new Date());


			businessProjectDO.setOrgId(bizFinancialBudgetFillingVO.getOrgId());
			businessProjectDO.setDeptId(bizFinancialBudgetFillingVO.getDeptId());
			businessProjectDO.setAreaCode(bizFinancialBudgetFillingVO.getAreaCode());
			businessProjectDO.setProjectName(bizFinancialBudgetFillingVO.getProjectName());
			businessProjectDO.setProjectContent(bizFinancialBudgetFillingVO.getProjectContent());



			int result1 = financialBusinessProjectDao.insertSelective(businessProjectDO);
			String projectId = businessProjectDO.getId();
			bizFinancialBudgetFillingVO.setProjectId(projectId);

			BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo = LsBeanUtils.copyProperties(bizFinancialBudgetFillingVO, BizFinancialBudgetFillingDO.class);
			
			if(null!=bizFinancialBudgetFillingVO.getProjectPeriod()) {
				String[] period=bizFinancialBudgetFillingVO.getProjectPeriod();
				bizFinancialBudgetFillingDo.setProjectPeriod(period[0]+","+period[1]);
			}
			bizFinancialBudgetFillingDo.setApplicationDate(new Date());
			//总体目标
			List<OverallObjectiveVO> overallObjective=bizFinancialBudgetFillingVO.getOverallObjective();
			if(null!=overallObjective && overallObjective.size()>0) {
				for(int i=0;i<overallObjective.size();i++) {
					if(!ObjectUtils.isAllFieldNull(overallObjective.get(i))){
						OverallObjectiveDO overallObjectiveDO=new OverallObjectiveDO();
						overallObjectiveDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
						overallObjectiveDO.setTargetContent(isNull(overallObjective.get(i).getTargetContent()+""));
						if (overallObjectiveDao.insert(overallObjectiveDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}
			
			//产出指标
			List<OutPutIndexQueryVO> outputIndex=bizFinancialBudgetFillingVO.getOutputIndex();
			if(null!=outputIndex && outputIndex.size()>0) {
				for(int i=0;i<outputIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(outputIndex.get(i))){
						OutPutIndexDO outputindexDo=new OutPutIndexDO();
						outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
						outputindexDo.setBudgetId(bizFinancialBudgetFillingDo.getId());
						outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
						outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
						outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));
						
						outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
						outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
						outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
						outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
						if (outPutIndexDao.insert(outputindexDo) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}

			//效益指标
			List<OutPutIndexQueryVO> benefitIndex=bizFinancialBudgetFillingVO.getBenefitIndex();
			if(null!=benefitIndex && benefitIndex.size()>0) {
				for(int i=0;i<benefitIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(benefitIndex.get(i))){
						BenefitIndexDO benefitIndexDO=new BenefitIndexDO();
						benefitIndexDO.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
						benefitIndexDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
						benefitIndexDO.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
						benefitIndexDO.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));
						benefitIndexDO.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
						
						benefitIndexDO.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
						benefitIndexDO.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
						benefitIndexDO.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
						benefitIndexDO.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
						if (benefitIndexDao.insert(benefitIndexDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}

			//满意度指标
			List<OutPutIndexQueryVO> satisfactionIndex = bizFinancialBudgetFillingVO.getSatisfactionIndex();
			if(  null!= satisfactionIndex && satisfactionIndex.size()>0) {
				for(int i=0;i<satisfactionIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(satisfactionIndex.get(i))){
						SatisfactionIndexDO satisfactionIndexDO=new SatisfactionIndexDO();
						satisfactionIndexDO.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
						satisfactionIndexDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
						satisfactionIndexDO.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
						satisfactionIndexDO.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));
						satisfactionIndexDO.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
						
						satisfactionIndexDO.setThreeClassIndex(isNull(satisfactionIndex.get(i).getThreeClassIndex()+""));
						satisfactionIndexDO.setIndexProperties(isNull(satisfactionIndex.get(i).getIndexProperties()+""));
						satisfactionIndexDO.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
						satisfactionIndexDO.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
						if (satisfactionIndexDao.insert(satisfactionIndexDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}

			int result = financialBudgetFillingDao.insertSelective(bizFinancialBudgetFillingDo);
			if (result > 0) {
				bizFinancialBudgetFillingVO.setId(bizFinancialBudgetFillingDo.getId());
				return bizFinancialBudgetFillingVO;
			}
		}catch (Exception e){
			e.printStackTrace();
		}
		return null;
	}



	/**
	 * 预算填报项目 -->申请 删除 逻辑删除,更新delete相关字段
	 * @param id
	 * @return
	 */
	@Override
	public Boolean deleteById(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		//接口需要加参数，获取当前登录人
		//String deleteBy = currentUtils.getUserName();
		Date deleteTime = new Date();
		return financialBudgetFillingDao.deleteById(bizFinancialBudgetFillingVO.getId(),bizFinancialBudgetFillingVO.getDeleteBy(),bizFinancialBudgetFillingVO.getDeleteTime());
	}

	/**
	 * 预算填报项目 -->申请 修改
	 * @param bizFinancialBudgetFillingVO
	 * @return
	 */
	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizFinancialBudgetFillingVO update(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo = LsBeanUtils.copyProperties(bizFinancialBudgetFillingVO, BizFinancialBudgetFillingDO.class);
		bizFinancialBudgetFillingDo.setId(bizFinancialBudgetFillingVO.getId());

		//bizFinancialBudgetFillingDo.setUpdateBy(currentUtils.getUserName());
		bizFinancialBudgetFillingDo.setUpdateTime(new Date());
		if(null!=bizFinancialBudgetFillingVO.getProjectPeriod()) {
			String[] period=bizFinancialBudgetFillingVO.getProjectPeriod();
			System.out.println(period[0]+","+period[1]);
			bizFinancialBudgetFillingDo.setProjectPeriod(period[0]+","+period[1]);
		}
		
		//总体目标
		List<OverallObjectiveVO> overallObjective=bizFinancialBudgetFillingVO.getOverallObjective();
		if(null!=overallObjective) {
			for(int i=0;i<overallObjective.size();i++) {
				if(!ObjectUtils.isAllFieldNull(overallObjective.get(i))){
					OverallObjectiveDO overallObjectiveDO=new OverallObjectiveDO();
					overallObjectiveDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
					overallObjectiveDO.setTargetContent(isNull(overallObjective.get(i).getTargetContent()+""));
					if (StringUtils.isNotEmpty(overallObjective.get(i).getId())) {
						overallObjectiveDO.setId(isNull(overallObjective.get(i).getId()+""));
	                    if (overallObjectiveDao.updateByPrimaryKey(overallObjectiveDO) < 1) {
	                        throw new RuntimeException("无法修改成功，请检查数据。");
	                    }
	                } else {
	                    if (overallObjectiveDao.insert(overallObjectiveDO) < 1) {
	                        throw new RuntimeException("无法保存成功，请检查数据。");
	                    }
	                }
				}
			}
		}
		
		//产出指标
		List<OutPutIndexQueryVO> outputIndex=bizFinancialBudgetFillingVO.getOutputIndex();
		if(null!=outputIndex) {
			if(outputIndex.size()>0) {
				for(int i=0;i<outputIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(outputIndex.get(i))){
						OutPutIndexDO outputindexDo=new OutPutIndexDO();
						outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
						outputindexDo.setBudgetId(bizFinancialBudgetFillingDo.getId());
						outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
						outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
						outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));
						
						outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
						outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
						outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
						outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
						if (StringUtils.isNotEmpty(outputIndex.get(i).getId())) {
						    outputindexDo.setId(isNull(outputIndex.get(i).getId()+""));
		                    if (outPutIndexDao.updateByPrimaryKey(outputindexDo) < 1) {
		                        throw new RuntimeException("无法修改成功，请检查数据。");
		                    }
		                } else {
		                    if (outPutIndexDao.insert(outputindexDo) < 1) {
		                        throw new RuntimeException("无法保存成功，请检查数据。");
		                    }
		                }
					}
				}
			}
		}
		
		//效益指标
		List<OutPutIndexQueryVO> benefitIndex=bizFinancialBudgetFillingVO.getBenefitIndex();
		if(null!=benefitIndex) {
			if(benefitIndex.size()>0) {
				for(int i=0;i<benefitIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(benefitIndex.get(i))){
						BenefitIndexDO benefitIndexDO=new BenefitIndexDO();
						benefitIndexDO.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
						benefitIndexDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
						benefitIndexDO.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
						benefitIndexDO.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));
						benefitIndexDO.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
						
						benefitIndexDO.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
						benefitIndexDO.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
						benefitIndexDO.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
						benefitIndexDO.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
		                if (StringUtils.isNotEmpty(benefitIndex.get(i).getId())) {
						    benefitIndexDO.setId(isNull(benefitIndex.get(i).getId()+""));
		                    if (benefitIndexDao.updateByPrimaryKey(benefitIndexDO) < 1) {
		                        throw new RuntimeException("无法修改成功，请检查数据。");
		                    }
		                } else {
		                    if (benefitIndexDao.insert(benefitIndexDO) < 1) {
		                        throw new RuntimeException("无法保存成功，请检查数据。");
		                    }
		                }
					}
				}
			}
		}

		//满意度指标
		List<OutPutIndexQueryVO> satisfactionIndex = bizFinancialBudgetFillingVO.getSatisfactionIndex();
		if(  null != satisfactionIndex && satisfactionIndex.size()>0) {
			for(int i=0;i<satisfactionIndex.size();i++) {
				if(!ObjectUtils.isAllFieldNull(satisfactionIndex.get(i))){
					SatisfactionIndexDO satisfactionIndexDO=new SatisfactionIndexDO();
					satisfactionIndexDO.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
					satisfactionIndexDO.setBudgetId(bizFinancialBudgetFillingDo.getId());
					satisfactionIndexDO.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
					satisfactionIndexDO.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));
					satisfactionIndexDO.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
					
					satisfactionIndexDO.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
					satisfactionIndexDO.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
					satisfactionIndexDO.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
					satisfactionIndexDO.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
	                if (StringUtils.isNotEmpty(satisfactionIndex.get(i).getId())) {
	                    satisfactionIndexDO.setId(isNull(satisfactionIndex.get(i).getId()+""));
	                    if (satisfactionIndexDao.updateByPrimaryKey(satisfactionIndexDO) < 1) {
	                        throw new RuntimeException("无法修改成功，请检查数据。");
	                    }
	                } else {
	                    if (satisfactionIndexDao.insert(satisfactionIndexDO) < 1) {
	                        throw new RuntimeException("无法保存成功，请检查数据。");
	                    }
	                }
				}
			}
		}
		
		int result= financialBudgetFillingDao.updateByPrimaryKey(bizFinancialBudgetFillingDo);
		if(result>0){
			return bizFinancialBudgetFillingVO;
		}
		return null;
	}

	/**
	 * 预算填报项目 -->申请  条件分页查询
	 * @param bizFinancialBudgetFillingVO
	 * @param page
	 * @param size
	 * @return
	 */
	@Override
	public PageInfo<List<Map>> findByPage(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO, Integer page, Integer size) {
		Page<List<Map>> listPage = PageHelper.startPage(page, size);

		//获取当前用户部门id   用于权限控制
		String deptId = bizFinancialBudgetFillingVO.getDeptId();

		/*for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			String s = e.getCode()+"";

			if (s.equals(bizFinancialBudgetFillingVO.getFindingsAudit())) {
				bizFinancialBudgetFillingVO.setFindingsAudit(e.getMessage());
			}
		}*/
		financialBudgetFillingDao.findByPage(bizFinancialBudgetFillingVO,deptId);
		return listPage.toPageInfo();
	}

	/**
	 * 预算填报项目 -->申请  提交申请
	 * @param bizFinancialBudgetFillingVO
	 * @return
	 */
	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizFinancialBudgetFillingVO applicationSub(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo = null;
		if (StringUtils.isEmpty(bizFinancialBudgetFillingVO.getId())) {
			//为空,未保存   调用保存
			try {
				BizFinancialBudgetFillingVO VO = saveBizFinancialBudgetFilling(bizFinancialBudgetFillingVO);
				bizFinancialBudgetFillingDo = LsBeanUtils.copyProperties(VO, BizFinancialBudgetFillingDO.class);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}else {
			bizFinancialBudgetFillingDo = LsBeanUtils.copyProperties(bizFinancialBudgetFillingVO, BizFinancialBudgetFillingDO.class);
			bizFinancialBudgetFillingDo.setId(bizFinancialBudgetFillingVO.getId());
		}
		//当申请处室和申请日期不为空时并且状态为:未提交,或者驳回
		if (ApprovalTypeEnum.fw.getMessage().equals(bizFinancialBudgetFillingDo.getFindingsAudit())||ApprovalTypeEnum.fb.getMessage().equals(bizFinancialBudgetFillingDo.getFindingsAudit())
				&& StringUtils.isNotEmpty(bizFinancialBudgetFillingVO.getApplicationOffice())
				&& StringUtils.isNotEmpty(bizFinancialBudgetFillingVO.getApplicationDate()+"")) {
			bizFinancialBudgetFillingDo.setFindingsAudit(ApprovalTypeEnum.fy.getMessage());
			//当为驳回时,清空上一次有关审核的数据
			bizFinancialBudgetFillingDo.setAuditor("");
			bizFinancialBudgetFillingDo.setAuditDate(null);
			bizFinancialBudgetFillingDo.setAuditOpinions("");
		}
		bizFinancialBudgetFillingDo.setDeleteBy("-1");
		bizFinancialBudgetFillingDo.setDeleteTime(null);
		int result= financialBudgetFillingDao.updateByPrimaryKey(bizFinancialBudgetFillingDo);
		if(result>0){
			return bizFinancialBudgetFillingVO;
		}
		return null;
	}

	/**
	 * 预算填报项目 审核
	 * @param bizFinancialBudgetFillingVO
	 * @return
	 */
	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizFinancialBudgetFillingVO audit(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo = LsBeanUtils.copyProperties(bizFinancialBudgetFillingVO, BizFinancialBudgetFillingDO.class);
		bizFinancialBudgetFillingDo.setId(bizFinancialBudgetFillingVO.getId());
		//审核人
		//bizFinancialBudgetFillingDo.setAuditor(currentUtils.getUserName());
		//审核日期
		bizFinancialBudgetFillingDo.setAuditDate(new Date());

		for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			if ((e.getCode()+"").equals(bizFinancialBudgetFillingDo.getFindingsAudit())) {
				bizFinancialBudgetFillingDo.setFindingsAudit(e.getMessage());
			}
		}
		int result= financialBudgetFillingDao.updateByPrimaryKey(bizFinancialBudgetFillingDo);
		if(result>0){
			return bizFinancialBudgetFillingVO;
		}
		return null;
	}

	/**
	 * 预算填报项目 -->审核  条件分页查询
	 * @param bizFinancialBudgetFillingVO
	 * @param page
	 * @param size
	 * @return
	 */
	@Override
	public PageInfo<List<Map>> findByPageOfAudit(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO, Integer page, Integer size) {
		Page<List<Map>> listPage = PageHelper.startPage(page, size);
		// 审核 "未审核"<--> 申请"已提交"  转换
		if ((ApprovalTypeEnum.fwa.getCode()+"").equals(bizFinancialBudgetFillingVO.getFindingsAudit())) {
			//查询条件为   已提交
			bizFinancialBudgetFillingVO.setFindingsAudit(ApprovalTypeEnum.fy.getMessage());
		}
		List<String> array = new ArrayList<String>();
		if (StringUtils.isEmpty(bizFinancialBudgetFillingVO.getFindingsAudit())) {
			//查询条件集合
			array.add(ApprovalTypeEnum.fy.getMessage());
			array.add(ApprovalTypeEnum.fa.getMessage());
			array.add(ApprovalTypeEnum.fb.getMessage());
		}
		for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			if (e.getCode().toString().equals(bizFinancialBudgetFillingVO.getFindingsAudit())) {
				bizFinancialBudgetFillingVO.setFindingsAudit(e.getMessage());
			}
		}
		List<BizFinancialBudgetFillingDO> byPageOfAudit = financialBudgetFillingDao.findByPageOfAudit(bizFinancialBudgetFillingVO,array);

		//过滤显示   已提交-->未审核
		for (BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo : byPageOfAudit) {
			if ((ApprovalTypeEnum.fy.getMessage()).equals(bizFinancialBudgetFillingDo.getFindingsAudit())) {
				bizFinancialBudgetFillingDo.setFindingsAudit(ApprovalTypeEnum.fwa.getMessage());
			}
		}
		return listPage.toPageInfo();
	}

	@Override
	public BizFinancialBudgetFillingVO findInfoById(String id) {
		BizFinancialBudgetFillingDO gg = financialBudgetFillingDao.selectByPrimaryKey(id);
		BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO1 = LsBeanUtils.copyProperties(gg, BizFinancialBudgetFillingVO.class);
		String w=gg.getProjectPeriod();
		if(null!=w) {
			String[] q=w.split(",");
			bizFinancialBudgetFillingVO1.setProjectPeriod(q);
		}
		
		//总体目标
		Example exampleOver = new Example(OverallObjectiveDO.class);
		Criteria criteriaOver = exampleOver.createCriteria();
		criteriaOver.andEqualTo("budgetId", id);
		List<OverallObjectiveDO>  overList =  overallObjectiveDao.selectByExample(exampleOver);
		List<OverallObjectiveVO> overallObjectiveList=new ArrayList<>();
		
		if(overList!=null) {
			for(int i=0;i<overList.size();i++) {
				OverallObjectiveVO overallObjectiveVO=new OverallObjectiveVO();
				overallObjectiveVO.setId(isNull(overList.get(i).getId()+""));
				overallObjectiveVO.setTargetContent(isNull(overList.get(i).getTargetContent()+""));
				overallObjectiveList.add(overallObjectiveVO);
				bizFinancialBudgetFillingVO1.setOverallObjective(overallObjectiveList);
			}
		}
		
		//产出指标
		Example example = new Example(OutPutIndexDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("budgetId", id);
		List<OutPutIndexDO>  outputIndex  =  outPutIndexDao.selectByExample(example);
		List<OutPutIndexQueryVO> outputIndexList=new ArrayList<>();
		
		if(outputIndex!=null) {
			for(int i=0;i<outputIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(outputIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));

				outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
				outputIndexList.add(outputindexDo);
				bizFinancialBudgetFillingVO1.setOutputIndex(outputIndexList);
			}
		}
		
		//效益指标
		Example example1 = new Example(BenefitIndexDO.class);
		Criteria criteria1 = example1.createCriteria();
		criteria1.andEqualTo("budgetId", id);
		List<BenefitIndexDO>  benefitIndex  =  benefitIndexDao.selectByExample(example1);
		List<OutPutIndexQueryVO> benefitIndexList=new ArrayList<>();
		if(benefitIndex!=null) {
			for(int i=0;i<benefitIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(benefitIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
				
				outputindexDo.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
				benefitIndexList.add(outputindexDo);
				bizFinancialBudgetFillingVO1.setBenefitIndex(benefitIndexList);
			}
		}

		//满意度指标  satisfactionIndex
		Example exampleSatisfaction = new Example(SatisfactionIndexDO.class);
		Criteria criteriaSatisfaction = exampleSatisfaction.createCriteria();
		criteriaSatisfaction.andEqualTo("budgetId", id);
		List<SatisfactionIndexDO>  satisfactionIndex  =  satisfactionIndexDao.selectByExample(exampleSatisfaction);
		List<OutPutIndexQueryVO> satisfactionIndexList = new ArrayList<>();
		if(satisfactionIndex !=null && satisfactionIndex.size() > 0) {
			for(int i=0;i<satisfactionIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(satisfactionIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
				
				outputindexDo.setThreeClassIndex(isNull(satisfactionIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(satisfactionIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
				satisfactionIndexList.add(outputindexDo);
				bizFinancialBudgetFillingVO1.setSatisfactionIndex(satisfactionIndexList);
			}
		}
		
		return bizFinancialBudgetFillingVO1;
	}
	@Override
	public List<BizFinancialBudgetFillingVO> findInfoByProjectId(BizFinancialBudgetFillingVO bizFinancialBudgetFillingVO) {
		String id = bizFinancialBudgetFillingVO.getId();
		String projectId = bizFinancialBudgetFillingVO.getProjectId();
		List<BizFinancialBudgetFillingDO> bizFinancialBudgetFillingDOS = financialBudgetFillingDao.selectByProjectId(projectId);
		ArrayList<BizFinancialBudgetFillingVO> bizFinancialBudgetFillingVOs = new ArrayList<>();
		for (BizFinancialBudgetFillingDO bizFinancialBudgetFillingDo : bizFinancialBudgetFillingDOS) {
			BizFinancialBudgetFillingVO bizFinancial = new BizFinancialBudgetFillingVO();
			bizFinancial=  LsBeanUtils.copyProperties(bizFinancialBudgetFillingDOS,BizFinancialBudgetFillingVO.class);
			bizFinancialBudgetFillingVOs.add(bizFinancial);
		}
		return bizFinancialBudgetFillingVOs;
	}
	/**
	 * @Description: 删除预算附件
	 * @return ResponseWrapper
	 */
	@Override
	public Boolean deleteAttachById(String id) {
		return financialBudgetFillingDao.deleteAttachById(id);
	}
	
	//移动端-项目年度汇总 
	@Override
	public List<Map> budgetSummary(String years){
		return financialBudgetFillingDao.budgetSummary(years);
	}

}
