package com.unis.financial.server.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ObjectUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.financial.common.vo.BizFinancialPresentationVO;
import com.unis.financial.server.dao.FinancialDataPresentationDao;
import com.unis.financial.server.entity.father.BizFinancialPresentationDO;
import com.unis.financial.server.service.FinancialDataPresentationService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialDataPresentationServiceImpl
 * @ProjectName FinancialDataPresentationServiceImpl
 * @Description: 应急台账的业务层
 * @date
 */
@Service
public class FinancialDataPresentationServiceImpl implements FinancialDataPresentationService {

    //@Autowired
    //private FinancialDomain financialDomain;
    @Autowired
    private FinancialDataPresentationDao financialDataPresentationDao;


    @Override
    public BizFinancialPresentationVO saveFinancialDate(BizFinancialPresentationVO bizFinancialPresentationVO) {
        //初始化数据项
        bizFinancialPresentationVO.setCreateTime(new Date());
        bizFinancialPresentationVO.setDeleteBy("-1");
        bizFinancialPresentationVO.setDeleteTime(null);
        //初始状态未提交
        bizFinancialPresentationVO.setReportingStatus("0");
        //如果用户为企业
        //获取企业id
        //String userId = currentUtils.getUserId();
        //企业类别
        String enterpriseCategory = bizFinancialPresentationVO.getEnterpriseCategory();
        if ("购销企业".equals(enterpriseCategory)) {
            bizFinancialPresentationVO.setEnterpriseCategory("1");
        } else if ("加工企业".equals(enterpriseCategory)) {
            bizFinancialPresentationVO.setEnterpriseCategory("2");
        } else if ("其他企业".equals(enterpriseCategory)) {
            bizFinancialPresentationVO.setEnterpriseCategory("3");
        }
        //编制单位
        bizFinancialPresentationVO.setEstablishmentUnit(bizFinancialPresentationVO.getCreateBy());
        //创建人
        //编制日期
        bizFinancialPresentationVO.setEstablishmentTime(new Date());
        bizFinancialPresentationVO.setId(UUIDUtils.uuid());
        BizFinancialPresentationVO bizFinancialData = automaticGeneration(bizFinancialPresentationVO);
        //financialDao.insertSelective(bizFinancialPresentationDO);
        BizFinancialPresentationDO bizFinancialPresentationDO = LsBeanUtils.copyProperties(bizFinancialData, BizFinancialPresentationDO.class);
        int i = financialDataPresentationDao.insertSelective(bizFinancialPresentationDO);
        if (i > 0) {
            return bizFinancialData;
        }
        return null;
    }

    private BizFinancialPresentationVO automaticGeneration(BizFinancialPresentationVO bizFinancialPresentationVO) {
        try {
            BigDecimal salesIncome = bizFinancialPresentationVO.getSalesIncome();//营业收入
            BigDecimal salesCost = bizFinancialPresentationVO.getSalesCost();//营业成本
            //毛利率
            if (salesIncome != null && salesCost != null) {
                if (salesIncome.compareTo(new BigDecimal(0)) != 0) {//除数不能为0
                    BigDecimal grossInterestRate = (salesIncome.subtract(salesCost)).divide(salesIncome, 4, BigDecimal.ROUND_HALF_EVEN);
                    bizFinancialPresentationVO.setGrossInterestRate(grossInterestRate);
                }
            }

            //毛利
            if (salesIncome != null && salesCost != null) {
                BigDecimal grossInterest = salesIncome.subtract(salesCost);
                bizFinancialPresentationVO.setGrossInterest(grossInterest);
            }

            //资产负债率 = (负债总额 ÷ 资产总额) × 100% 
            BigDecimal totalLiabilities = bizFinancialPresentationVO.getTotalLiabilities();//负债总额
            BigDecimal totalAssets = bizFinancialPresentationVO.getTotalAssets();//资产总额
            if (totalAssets.compareTo(new BigDecimal(0)) != 0) {//除数不能为0
                BigDecimal assetLiabilityRatio = totalLiabilities.divide(totalAssets, 4, BigDecimal.ROUND_HALF_EVEN);//资产负债率
                bizFinancialPresentationVO.setAssetLiabilityRatio(assetLiabilityRatio);
            }

            //销售费用率  = （粮油销售成本 / 营业收入) x 100%
            BigDecimal costOfGrainAndOilSales = bizFinancialPresentationVO.getCostOfGrainAndOilSales(); //粮油销售成本
            BigDecimal salesIncome1 = bizFinancialPresentationVO.getSalesIncome(); //营业收入
            if (salesIncome1.compareTo(new BigDecimal(0)) != 0) {
                BigDecimal ratioOfExpensesToSales = costOfGrainAndOilSales.divide(salesIncome1, 4, BigDecimal.ROUND_HALF_EVEN);
                bizFinancialPresentationVO.setRatioOfExpensesToSales(ratioOfExpensesToSales);
            }
            //销售利润率 = 利润总额 / 营业收入 × 100%
            BigDecimal totalProfit = bizFinancialPresentationVO.getTotalProfit(); //利润总额
            if (salesIncome1.compareTo(new BigDecimal(0)) != 0) {
                BigDecimal profitRatioOfSales = totalProfit.divide(salesIncome1, 4, BigDecimal.ROUND_HALF_EVEN); //销售利润率
                bizFinancialPresentationVO.setProfitRatioOfSales(profitRatioOfSales);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return bizFinancialPresentationVO;
    }


    @Override
    public Boolean updateFinancialDate(BizFinancialPresentationVO bizFinancialPresentationVO) {

        //企业类别
        String enterpriseCategory = bizFinancialPresentationVO.getEnterpriseCategory();
        if (StringUtils.isNotEmpty(enterpriseCategory)) {
            if ("购销企业".equals(enterpriseCategory)) {
                bizFinancialPresentationVO.setEnterpriseCategory("1");
            } else if ("加工企业".equals(enterpriseCategory)) {
                bizFinancialPresentationVO.setEnterpriseCategory("2");
            } else if ("其他企业".equals(enterpriseCategory)) {
                bizFinancialPresentationVO.setEnterpriseCategory("3");
            }
        }
        //bizFinancialPresentationVO.setUpdateBy(currentUtils.getUserName());
        bizFinancialPresentationVO.setUpdateTime(new Date());
        BizFinancialPresentationVO bizFinancialData = automaticGeneration(bizFinancialPresentationVO);
        BizFinancialPresentationDO bizFinancialPresentationDO = LsBeanUtils.copyProperties(bizFinancialData, BizFinancialPresentationDO.class);
        int result = financialDataPresentationDao.updateByPrimaryKeySelective(bizFinancialPresentationDO);
        //int result = financialDao.updateByPrimaryKeySelective(bizFinancialPresentationDO);
        if (result > 0) {
            return true;
        }
        return false;
    }

    @Override
    public Boolean deleteFinancialDate(BizFinancialPresentationVO bizFinancialPresentationVO) {
        return financialDataPresentationDao.deleteByPrimaryKey(bizFinancialPresentationVO.getId(), bizFinancialPresentationVO.getDeleteBy(), bizFinancialPresentationVO.getDeleteTime());
    }

    @Override
    public BizFinancialPresentationVO getFinancialDate(String id, String enterpriseCategory) {

        BizFinancialPresentationDO bizFinancialPresentationDO = financialDataPresentationDao.selectByPrimaryKey(id, enterpriseCategory);
        BizFinancialPresentationVO bizFinancialPresentationVO = LsBeanUtils.copyProperties(bizFinancialPresentationDO, BizFinancialPresentationVO.class);
        if (null == bizFinancialPresentationVO) {
            bizFinancialPresentationVO = new BizFinancialPresentationVO();
        }
        return bizFinancialPresentationVO;
    }

    @Override
    public Boolean subFinancialDate(BizFinancialPresentationVO bizFinancialPresentationVO) {
        BizFinancialPresentationDO bizFinancialPresentationDO = null;
        if (StringUtils.isEmpty(bizFinancialPresentationVO.getId())) {
            //为空,未保存   调用保存
            try {
                BizFinancialPresentationVO vo = saveFinancialDate(bizFinancialPresentationVO);
                bizFinancialPresentationDO = LsBeanUtils.copyProperties(vo, BizFinancialPresentationDO.class);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            bizFinancialPresentationDO = LsBeanUtils.copyProperties(bizFinancialPresentationVO, BizFinancialPresentationDO.class);
        }
        String category = bizFinancialPresentationDO.getEnterpriseCategory();
        if ("购销企业".equals(category)) {
            bizFinancialPresentationDO.setEnterpriseCategory("1");
        } else if ("加工企业".equals(category)) {
            bizFinancialPresentationDO.setEnterpriseCategory("2");
        } else if ("其他企业".equals(category)) {
            bizFinancialPresentationDO.setEnterpriseCategory("3");
        }
        bizFinancialPresentationDO.setReportingStatus("1");
        int result = financialDataPresentationDao.updateByPrimaryKeySelective(bizFinancialPresentationDO);
        if (result > 0) {
            return true;
        }
        return false;
    }

    @Override
    public PageInfo<List<Map>> getFinancialDataByPage(String establishmentUnit, String year, String month, String orgId, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        //获取当前用户部门id   用于权限控制
        String deptId = "";
        financialDataPresentationDao.findByPage(establishmentUnit,orgId, year, month);
        return listPage.toPageInfo();
    }

    @Override
    public PageInfo<List<Map>> getDataByPage(String establishmentUnit, String reportYear, String reportMonth, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        //List<BizFinancialPresentationDO> dataByPage = financialDao.getDataByPage(establishmentUnit, reportYear, reportMonth, deptId);
        List<BizFinancialPresentationDO> dataByPage = financialDataPresentationDao.getDataByPage(establishmentUnit, reportYear, reportMonth);
        for (BizFinancialPresentationDO bizFinancialPresentationDO : dataByPage) {
            String enterpriseCategory = bizFinancialPresentationDO.getEnterpriseCategory();
            if ("1".equals(enterpriseCategory)) {
                bizFinancialPresentationDO.setEnterpriseCategory("购销企业");
            } else if ("2".equals(enterpriseCategory)) {
                bizFinancialPresentationDO.setEnterpriseCategory("加工企业");
            } else if ("3".equals(enterpriseCategory)) {
                bizFinancialPresentationDO.setEnterpriseCategory("其他企业");
            }
        }
        return listPage.toPageInfo();
    }

    @Override
    public PageInfo<List<Map>> countDataPage(String reportYear, String reportMonth, Integer page, Integer size) {
        Page<List<Map>> listPage = PageHelper.startPage(page, size);
        List<BizFinancialPresentationDO> dos = financialDataPresentationDao.countDataPage(reportYear, reportMonth);
        return listPage.toPageInfo();
    }

    @Override
    public Map<String, BizFinancialPresentationDO> drillData(String reportYear, String reportMonth) {
        Map<String, BizFinancialPresentationDO> stringListHashMap = new HashMap<String, BizFinancialPresentationDO>();
        BizFinancialPresentationDO gx = financialDataPresentationDao.categoryData(reportYear, reportMonth, "1");
        BizFinancialPresentationDO jg = financialDataPresentationDao.categoryData(reportYear, reportMonth, "2");
        BizFinancialPresentationDO qt = financialDataPresentationDao.categoryData(reportYear, reportMonth, "3");
        if (null == gx) {
            stringListHashMap.put("购销企业", new BizFinancialPresentationDO());
        } else {
            stringListHashMap.put("购销企业", gx);
        }
        if (null == jg) {
            stringListHashMap.put("加工企业", new BizFinancialPresentationDO());
        } else {
            stringListHashMap.put("加工企业", jg);
        }
        if (null == qt) {
            stringListHashMap.put("其他企业", new BizFinancialPresentationDO());
        } else {
            stringListHashMap.put("其他企业", qt);
        }
        //汇总数据
        BizFinancialPresentationDO hz = financialDataPresentationDao.countData(reportYear, reportMonth);
        //毛利率资产负债率
        BizFinancialPresentationVO bizFinancialPresentationVO = LsBeanUtils.copyProperties(hz, BizFinancialPresentationVO.class);
        BizFinancialPresentationVO bizFinancialData = automaticGeneration(bizFinancialPresentationVO);
        BizFinancialPresentationDO bizFinancialPresentationDO = LsBeanUtils.copyProperties(bizFinancialData, BizFinancialPresentationDO.class);
        stringListHashMap.put("合计", bizFinancialPresentationDO);
        return stringListHashMap;
    }


}
