package com.unis.financial.server.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ObjectUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.financial.common.vo.BizFinancialPresentationVO;
import com.unis.financial.common.vo.BizPerformanceManagementVO;
import com.unis.financial.common.vo.OutPutIndexQueryVO;
import com.unis.financial.common.vo.OverallObjectiveVO;
import com.unis.financial.server.dao.BenefitIndexDao;
import com.unis.financial.server.dao.FinancialBudgetFillingDao;
import com.unis.financial.server.dao.FinancialDataPresentationDao;
import com.unis.financial.server.dao.FinancialPerformanceManagementDao;
import com.unis.financial.server.dao.OutPutIndexDao;
import com.unis.financial.server.dao.OverallObjectiveDao;
import com.unis.financial.server.dao.SatisfactionIndexDao;
import com.unis.financial.server.entity.father.BenefitIndexDO;
import com.unis.financial.server.entity.father.BizFinancialBudgetFillingDO;
import com.unis.financial.server.entity.father.BizFinancialPresentationDO;
import com.unis.financial.server.entity.father.BizPerformanceManagementDO;
import com.unis.financial.server.entity.father.OutPutIndexDO;
import com.unis.financial.server.entity.father.OverallObjectiveDO;
import com.unis.financial.server.entity.father.SatisfactionIndexDO;
import com.unis.financial.server.enums.ApprovalTypeEnum;
import com.unis.financial.server.service.FinancialDataPresentationService;
import com.unis.financial.server.service.FinancialPerformanceManagementService;

import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author wq
 * @version 1.0
 * @Title: FinancialDataPresentationServiceImpl
 * @ProjectName FinancialDataPresentationServiceImpl
 * @Description: 应急台账的业务层
 * @date
 */
@Service
public class FinancialPerformanceManagementServiceImpl implements FinancialPerformanceManagementService {


	@Autowired
	private FinancialPerformanceManagementDao financialPerformanceManagementDao;
	@Autowired
	private FinancialBudgetFillingDao financialBudgetFillingDao;
	
	@Autowired
	private OutPutIndexDao outPutIndexDao;
	
	@Autowired
	private BenefitIndexDao benefitIndexDao;

	@Autowired
	private SatisfactionIndexDao satisfactionIndexDao;
	
	@Autowired
	private OverallObjectiveDao overallObjectiveDao;
	
	
	@Override
	public BizPerformanceManagementVO findInfoById(String id) {
		BizPerformanceManagementDO gg = financialPerformanceManagementDao.selectByPrimaryKey(id);
		BizPerformanceManagementVO  bizPerformanceManagementVO1 = LsBeanUtils.copyProperties(gg, BizPerformanceManagementVO.class);
		//总体目标
		Example exampleOver = new Example(OverallObjectiveDO.class);
		Criteria criteriaOver = exampleOver.createCriteria();
		criteriaOver.andEqualTo("budgetId", id);
		List<OverallObjectiveDO>  overList =  overallObjectiveDao.selectByExample(exampleOver);
		List<OverallObjectiveVO> overallObjectiveList=new ArrayList<>();
		
		if(overList!=null) {
			for(int i=0;i<overList.size();i++) {
				OverallObjectiveVO overallObjectiveVO=new OverallObjectiveVO();
				overallObjectiveVO.setId(isNull(overList.get(i).getId()+""));
				overallObjectiveVO.setTargetContent(isNull(overList.get(i).getTargetContent()+""));
				overallObjectiveList.add(overallObjectiveVO);
				bizPerformanceManagementVO1.setOverallObjective(overallObjectiveList);
			}
		}
		
		//产出指标
		Example example = new Example(OutPutIndexDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("budgetId", id);
		List<OutPutIndexDO>  outputIndex  =  outPutIndexDao.selectByExample(example);
		List<OutPutIndexQueryVO> outputIndexList=new ArrayList<>();
		
		if(outputIndex!=null) {
			for(int i=0;i<outputIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(outputIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));

				outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
				outputIndexList.add(outputindexDo);
				bizPerformanceManagementVO1.setOutputIndex(outputIndexList);
			}
		}
		
		//效益指标
		Example example1 = new Example(BenefitIndexDO.class);
		Criteria criteria1 = example1.createCriteria();
		criteria1.andEqualTo("budgetId", id);
		List<BenefitIndexDO>  benefitIndex  =  benefitIndexDao.selectByExample(example1);
		List<OutPutIndexQueryVO> benefitIndexList=new ArrayList<>();
		if(benefitIndex!=null) {
			for(int i=0;i<benefitIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(benefitIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
				
				outputindexDo.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
				benefitIndexList.add(outputindexDo);
				bizPerformanceManagementVO1.setBenefitIndex(benefitIndexList);
			}
		}

		//满意度指标  satisfactionIndex
		Example exampleSatisfaction = new Example(BenefitIndexDO.class);
		Criteria criteriaSatisfaction = exampleSatisfaction.createCriteria();
		criteriaSatisfaction.andEqualTo("budgetId", id);
		List<SatisfactionIndexDO>  satisfactionIndex  =  satisfactionIndexDao.selectByExample(exampleSatisfaction);
		List<OutPutIndexQueryVO> satisfactionIndexList = new ArrayList<>();
		if(satisfactionIndex !=null && satisfactionIndex.size() > 0) {
			for(int i=0;i<satisfactionIndex.size();i++) {
				OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
				outputindexDo.setId(isNull(satisfactionIndex.get(i).getId()+""));
				outputindexDo.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
				outputindexDo.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
				outputindexDo.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));;
				outputindexDo.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
				
				outputindexDo.setThreeClassIndex(isNull(satisfactionIndex.get(i).getThreeClassIndex()+""));
				outputindexDo.setIndexProperties(isNull(satisfactionIndex.get(i).getIndexProperties()+""));
				outputindexDo.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
				outputindexDo.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
				satisfactionIndexList.add(outputindexDo);
				bizPerformanceManagementVO1.setSatisfactionIndex(satisfactionIndexList);
			}
		}
		
		return bizPerformanceManagementVO1;
	}

	//判断字符串是否为空
    public String isNull(String key) {
    	String str="";
    	if("null".equals(key)) {
    		str="";
    	}else {
    		str=key;
    	}
    	return  str;
    }
	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizPerformanceManagementVO saveBizPerformanceManagement(BizPerformanceManagementVO bizPerformanceManagementVO) {
		try {
			//保存项目填报相关信息
			//部门ID
			System.out.println(bizPerformanceManagementVO.getFillDate());
			//bizPerformanceManagementVO.setDeptId(String.valueOf(currentUtils.getDeptId()));
			//初始状态未提交
			bizPerformanceManagementVO.setFindingsAudit(ApprovalTypeEnum.pw.getMessage());
			bizPerformanceManagementVO.setId(UUIDUtils.uuid());
			//bizPerformanceManagementVO.setCreateBy(currentUtils.getUserName());
			bizPerformanceManagementVO.setCreateTime(new Date());

			bizPerformanceManagementVO.setDeleteBy("-1");
			bizPerformanceManagementVO.setDeleteTime(null);
			//bizPerformanceManagementVO.setFillDate(new Date());
			BizPerformanceManagementDO bizPerformanceManagementDO = LsBeanUtils.copyProperties(bizPerformanceManagementVO, BizPerformanceManagementDO.class);
			
			//总体目标
			List<OverallObjectiveVO> overallObjective=bizPerformanceManagementVO.getOverallObjective();
			if(null!=overallObjective && overallObjective.size()>0) {
				for(int i=0;i<overallObjective.size();i++) {
					if(!ObjectUtils.isAllFieldNull(overallObjective.get(i))){
						OverallObjectiveDO overallObjectiveDO=new OverallObjectiveDO();
						overallObjectiveDO.setBudgetId(bizPerformanceManagementDO.getId());
						overallObjectiveDO.setTargetContent(isNull(overallObjective.get(i).getTargetContent()+""));
						if (overallObjectiveDao.insert(overallObjectiveDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}
			
			//产出指标
			List<OutPutIndexQueryVO> outputIndex=bizPerformanceManagementVO.getOutputIndex();
			if(null!=outputIndex && outputIndex.size()>0) {
				for(int i=0;i<outputIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(outputIndex.get(i))){
						OutPutIndexDO outputindexDo=new OutPutIndexDO();
						outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
						outputindexDo.setBudgetId(bizPerformanceManagementDO.getId());
						outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
						outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
						outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));
						
						outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
						outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
						outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
						outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
						if (outPutIndexDao.insert(outputindexDo) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}

			//效益指标
			List<OutPutIndexQueryVO> benefitIndex=bizPerformanceManagementVO.getBenefitIndex();
			if(null !=benefitIndex && benefitIndex.size()>0) {
				for(int i=0;i<benefitIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(benefitIndex.get(i))){
						BenefitIndexDO benefitIndexDO=new BenefitIndexDO();
						benefitIndexDO.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
						benefitIndexDO.setBudgetId(bizPerformanceManagementDO.getId());
						benefitIndexDO.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
						benefitIndexDO.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));
						benefitIndexDO.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
						
						benefitIndexDO.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
						benefitIndexDO.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
						benefitIndexDO.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
						benefitIndexDO.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
						if (benefitIndexDao.insert(benefitIndexDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}

			//满意度指标
			List<OutPutIndexQueryVO> satisfactionIndex = bizPerformanceManagementVO.getSatisfactionIndex();
			if(satisfactionIndex != null && satisfactionIndex.size()>0) {
				for(int i=0;i<satisfactionIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(satisfactionIndex.get(i))){
						SatisfactionIndexDO satisfactionIndexDO=new SatisfactionIndexDO();
						satisfactionIndexDO.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
						satisfactionIndexDO.setBudgetId(bizPerformanceManagementDO.getId());
						satisfactionIndexDO.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
						satisfactionIndexDO.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));
						satisfactionIndexDO.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
						
						satisfactionIndexDO.setThreeClassIndex(isNull(satisfactionIndex.get(i).getThreeClassIndex()+""));
						satisfactionIndexDO.setIndexProperties(isNull(satisfactionIndex.get(i).getIndexProperties()+""));
						satisfactionIndexDO.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
						satisfactionIndexDO.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
						if (satisfactionIndexDao.insert(satisfactionIndexDO) < 1) {
							throw new RuntimeException("无法保存成功，请检查数据。");
						}
					}
				}
			}
			
			
			int result = financialPerformanceManagementDao.insertSelective(bizPerformanceManagementDO);
			if (result > 0) {
				bizPerformanceManagementVO.setId(bizPerformanceManagementDO.getId());
				return bizPerformanceManagementVO;
			}
		}catch (Exception e){
			e.printStackTrace();
		}
		return null;
	}

	@Override
	public PageInfo<List<Map>> findByPage(BizPerformanceManagementVO bizPerformanceManagementVO, Integer page, Integer size) {

		//先获取填报 审核通过数据
		ArrayList<BizPerformanceManagementVO> bizPerformanceManagementVOs = new ArrayList<>();
		/*BizPerformanceManagementDO bizPerformance = new BizPerformanceManagementDO();
		String approve = ApprovalTypeEnum.pa.getMessage();
		//List<BizFinancialBudgetFillingDO> appList = financialBudgetFillingDao.findByAudit(approve, deptId);
		List<BizFinancialBudgetFillingDO> appList = financialBudgetFillingDao.findByAudit(approve);
		if(appList!=null && appList.size()>0) {
			for (BizFinancialBudgetFillingDO bizFinancialBudgetFillingDO : appList) {
				bizPerformance.setCreateBy(bizFinancialBudgetFillingDO.getCreateBy());
				bizPerformance.setCreateTime(bizFinancialBudgetFillingDO.getCreateTime());
				bizPerformance.setDeleteBy(bizFinancialBudgetFillingDO.getDeleteBy());
				bizPerformance.setDeleteTime(bizFinancialBudgetFillingDO.getDeleteTime());
				bizPerformance.setUpdateBy(bizFinancialBudgetFillingDO.getUpdateBy());
				bizPerformance.setUpdateTime(bizFinancialBudgetFillingDO.getUpdateTime());
				bizPerformance.setOrgId(bizFinancialBudgetFillingDO.getOrgId());
				bizPerformance.setDeptId(bizFinancialBudgetFillingDO.getDeptId());
				bizPerformance.setAreaCode(bizFinancialBudgetFillingDO.getAreaCode());
				bizPerformance.setProjectName(bizFinancialBudgetFillingDO.getProjectName());
				bizPerformance.setProjectContent(bizFinancialBudgetFillingDO.getProjectContent());
				bizPerformance.setAnnualTarget(bizFinancialBudgetFillingDO.getAnnualTarget());
				bizPerformance.setFillDate(bizFinancialBudgetFillingDO.getAuditDate());
				bizPerformance.setProjectId(bizFinancialBudgetFillingDO.getProjectId());
				//初始化状态
				bizPerformance.setFindingsAudit(ApprovalTypeEnum.pw.getMessage());
				//初始化绩效数据
				int i = financialPerformanceManagementDao.insertSelective(bizPerformance);
				if (i>0) {
					//已导入  更新填报表
					financialBudgetFillingDao.updateIsImport("1", bizFinancialBudgetFillingDO.getId());
				}
			}
		}*/
		Page<List<Map>> listPage = PageHelper.startPage(page, size);

		/*for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			String s = e.getCode()+"";
			if (s.equals(bizPerformanceManagementVO.getFindingsAudit())) {
				bizPerformanceManagementVO.setFindingsAudit(e.getMessage());
			}
		}*/
		//List<Map> byPage = financialPerformanceManagementDao.findByPage(bizPerformanceManagementVO, deptId);
		financialPerformanceManagementDao.findByPage(bizPerformanceManagementVO);
		return listPage.toPageInfo();
	}

	@Override
	public Boolean deleteById(BizPerformanceManagementVO bizPerformanceManagementVO) {
		//接口需新增参数
		//String deleteBy = currentUtils.getUserName();
		Date deleteTime = new Date();
		return  financialPerformanceManagementDao.deleteById(bizPerformanceManagementVO.getId(),bizPerformanceManagementVO.getDeleteBy(),bizPerformanceManagementVO.getDeleteTime());
	}

	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizPerformanceManagementVO applicationSub(BizPerformanceManagementVO bizPerformanceManagementVO) {


		bizPerformanceManagementVO.setId(bizPerformanceManagementVO.getId());
		//当申请处室和申请日期不为空时并且状态为:未提交
		if (ApprovalTypeEnum.pw.getMessage().equals(bizPerformanceManagementVO.getFindingsAudit())||ApprovalTypeEnum.pb.getMessage().equals(bizPerformanceManagementVO.getFindingsAudit())
				&&StringUtils.isNotEmpty(bizPerformanceManagementVO.getProjectName())) {
			bizPerformanceManagementVO.setFindingsAudit(ApprovalTypeEnum.py.getMessage());
			//当为驳回时,清空上一次有关审核的数据
			bizPerformanceManagementVO.setAuditor("");
			bizPerformanceManagementVO.setAuditDate(null);
			bizPerformanceManagementVO.setAuditOpinions("");
		}
		//当申请处室和申请日期不为空时并且状态为:未提交,或者驳回
		BizPerformanceManagementDO bizPerformanceManagementDO = LsBeanUtils.copyProperties(bizPerformanceManagementVO, BizPerformanceManagementDO.class);
		int result= financialPerformanceManagementDao.updateByPrimaryKey(bizPerformanceManagementDO);
		if(result>0){
			return bizPerformanceManagementVO;
		}
		return null;
	}

	@Override
	@Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
	public BizPerformanceManagementVO update(BizPerformanceManagementVO bizPerformanceManagementVO) {
		BizPerformanceManagementDO bizPerformanceManagementDO = LsBeanUtils.copyProperties(bizPerformanceManagementVO, BizPerformanceManagementDO.class);
		bizPerformanceManagementDO.setId(bizPerformanceManagementVO.getId());
		//bizPerformanceManagementDO.setUpdateBy(currentUtils.getUserName());
		bizPerformanceManagementDO.setUpdateTime(new Date());
		//申请日期
       /* bizFinancialBudgetFillingDO.setApplicationDate(new Date());
        bizFinancialBudgetFillingDO.setApplicationOffice(bizFinancialBudgetFillingVo.getApplicationOffice());*/
		if (StringUtils.isEmpty(bizPerformanceManagementDO.getFillDate().toString())) {
			bizPerformanceManagementDO.setFillDate(new Date());
		}
		
		
		//总体目标
		List<OverallObjectiveVO> overallObjective=bizPerformanceManagementVO.getOverallObjective();
		if(null!=overallObjective) {
			for(int i=0;i<overallObjective.size();i++) {
				if(!ObjectUtils.isAllFieldNull(overallObjective.get(i))){
					OverallObjectiveDO overallObjectiveDO=new OverallObjectiveDO();
					overallObjectiveDO.setBudgetId(bizPerformanceManagementDO.getId());
					overallObjectiveDO.setTargetContent(isNull(overallObjective.get(i).getTargetContent()+""));
					if (StringUtils.isNotEmpty(overallObjective.get(i).getId())) {
						overallObjectiveDO.setId(isNull(overallObjective.get(i).getId()+""));
	                    if (overallObjectiveDao.updateByPrimaryKey(overallObjectiveDO) < 1) {
	                        throw new RuntimeException("无法修改成功，请检查数据。");
	                    }
	                } else {
	                    if (overallObjectiveDao.insert(overallObjectiveDO) < 1) {
	                        throw new RuntimeException("无法保存成功，请检查数据。");
	                    }
	                }
				}
			}
		}
		
		//产出指标
		List<OutPutIndexQueryVO> outputIndex=bizPerformanceManagementVO.getOutputIndex();
		if(null!=outputIndex) {
			if(outputIndex.size()>0) {
				for(int i=0;i<outputIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(outputIndex.get(i))){
						OutPutIndexDO outputindexDo=new OutPutIndexDO();
						outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
						outputindexDo.setBudgetId(bizPerformanceManagementDO.getId());
						outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
						outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
						outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));
						
						outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
						outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
						outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
						outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
						if (StringUtils.isNotEmpty(outputIndex.get(i).getId())) {
						    outputindexDo.setId(isNull(outputIndex.get(i).getId()+""));
		                    if (outPutIndexDao.updateByPrimaryKey(outputindexDo) < 1) {
		                        throw new RuntimeException("无法修改成功，请检查数据。");
		                    }
		                } else {
		                    if (outPutIndexDao.insert(outputindexDo) < 1) {
		                        throw new RuntimeException("无法保存成功，请检查数据。");
		                    }
		                }
					}
				}
			}
		}
		
		//效益指标
		List<OutPutIndexQueryVO> benefitIndex=bizPerformanceManagementVO.getBenefitIndex();
		if(null!=benefitIndex) {
			if(benefitIndex.size()>0) {
				for(int i=0;i<benefitIndex.size();i++) {
					if(!ObjectUtils.isAllFieldNull(benefitIndex.get(i))){
						BenefitIndexDO benefitIndexDO=new BenefitIndexDO();
						benefitIndexDO.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
						benefitIndexDO.setBudgetId(bizPerformanceManagementDO.getId());
						benefitIndexDO.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
						benefitIndexDO.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));
						benefitIndexDO.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
						
						benefitIndexDO.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
						benefitIndexDO.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
						benefitIndexDO.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
						benefitIndexDO.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
		                if (StringUtils.isNotEmpty(benefitIndex.get(i).getId())) {
						    benefitIndexDO.setId(isNull(benefitIndex.get(i).getId()+""));
		                    if (benefitIndexDao.updateByPrimaryKey(benefitIndexDO) < 1) {
		                        throw new RuntimeException("无法修改成功，请检查数据。");
		                    }
		                } else {
		                    if (benefitIndexDao.insert(benefitIndexDO) < 1) {
		                        throw new RuntimeException("无法保存成功，请检查数据。");
		                    }
		                }
					}
				}
			}
		}

		//满意度指标
		List<OutPutIndexQueryVO> satisfactionIndex = bizPerformanceManagementVO.getSatisfactionIndex();
		if(satisfactionIndex != null && satisfactionIndex.size()>0) {
			for(int i=0;i<satisfactionIndex.size();i++) {
				if(!ObjectUtils.isAllFieldNull(satisfactionIndex.get(i))){
					SatisfactionIndexDO satisfactionIndexDO=new SatisfactionIndexDO();
					satisfactionIndexDO.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
					satisfactionIndexDO.setBudgetId(bizPerformanceManagementDO.getId());
					satisfactionIndexDO.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
					satisfactionIndexDO.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));
					satisfactionIndexDO.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
					
					satisfactionIndexDO.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
					satisfactionIndexDO.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
					satisfactionIndexDO.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
					satisfactionIndexDO.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
	                if (StringUtils.isNotEmpty(satisfactionIndex.get(i).getId())) {
	                    satisfactionIndexDO.setId(isNull(satisfactionIndex.get(i).getId()+""));
	                    if (satisfactionIndexDao.updateByPrimaryKey(satisfactionIndexDO) < 1) {
	                        throw new RuntimeException("无法修改成功，请检查数据。");
	                    }
	                } else {
	                    if (satisfactionIndexDao.insert(satisfactionIndexDO) < 1) {
	                        throw new RuntimeException("无法保存成功，请检查数据。");
	                    }
	                }
				}
			}
		}
		
		int result= financialPerformanceManagementDao.updateByPrimaryKey(bizPerformanceManagementDO);
		if(result>0){
			return bizPerformanceManagementVO;
		}
		return null;
	}

	@Override
	public BizPerformanceManagementVO audit(BizPerformanceManagementVO bizPerformanceManagementVO) {
		BizPerformanceManagementDO bizPerformanceManagementDO = LsBeanUtils.copyProperties(bizPerformanceManagementVO, BizPerformanceManagementDO.class);
		bizPerformanceManagementDO.setId(bizPerformanceManagementVO.getId());
		//审核人
		//bizPerformanceManagementDO.setAuditor(currentUtils.getUserName());
		//审核日期
		bizPerformanceManagementDO.setUpdateTime(new Date());
		for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			if ((e.getCode()+"").equals(bizPerformanceManagementDO.getFindingsAudit())) {
				bizPerformanceManagementDO.setFindingsAudit(e.getMessage());
			}
		}
		int result= financialPerformanceManagementDao.updateByPrimaryKey(bizPerformanceManagementDO);
		if(result>0){
			return bizPerformanceManagementVO;
		}
		return null;
	}

	@Override
	public PageInfo<List<Map>> findByPageOfAudit(BizPerformanceManagementVO bizPerformanceManagementVO, Integer page, Integer size) {
		Page<List<Map>> listPage = PageHelper.startPage(page, size);
		// 审核 "未审核"<--> 申请"已提交"  转换
		if ((ApprovalTypeEnum.pwa.getCode()+"").equals(bizPerformanceManagementVO.getFindingsAudit())) {
			//查询条件为   已提交
			bizPerformanceManagementVO.setFindingsAudit(ApprovalTypeEnum.py.getMessage());
		}
		List<String> array = new ArrayList<String>();
		if (StringUtils.isEmpty(bizPerformanceManagementVO.getFindingsAudit())) {
			//查询条件集合
			array.add(ApprovalTypeEnum.py.getMessage());
			array.add(ApprovalTypeEnum.pa.getMessage());
			array.add(ApprovalTypeEnum.pb.getMessage());
		}
		for (ApprovalTypeEnum e : ApprovalTypeEnum.values()) {
			if (e.getCode().toString().equals(bizPerformanceManagementVO.getFindingsAudit())) {
				bizPerformanceManagementVO.setFindingsAudit(e.getMessage());
			}
		}
		List<BizPerformanceManagementDO> byPageOfAudit = financialPerformanceManagementDao.findByPageOfAudit(bizPerformanceManagementVO,array);
		//过滤显示   已提交-->未审核
		for (BizPerformanceManagementDO bizPerformanceManagementDO : byPageOfAudit) {
			if ((ApprovalTypeEnum.py.getMessage()).equals(bizPerformanceManagementDO.getFindingsAudit())) {
				bizPerformanceManagementDO.setFindingsAudit(ApprovalTypeEnum.pwa.getMessage());
			}
		}
		return listPage.toPageInfo();
	}

	@Override
	public List<BizPerformanceManagementVO> findInfoByProjectId(BizPerformanceManagementVO bizPerformanceManagementVO) {
		String id = bizPerformanceManagementVO.getId();
		String projectId = bizPerformanceManagementVO.getProjectId();
		List<BizPerformanceManagementDO> bizList = financialPerformanceManagementDao.selectByProjectId(projectId);
		ArrayList<BizPerformanceManagementVO> bizPerformanceManagementVOs = new ArrayList<>();
		for (BizPerformanceManagementDO bizPerformanceManagementDO : bizList) {

			BizPerformanceManagementVO bizFinancial = new BizPerformanceManagementVO();
			int season = DateUtil.getSeason(bizPerformanceManagementVO.getFillDate());
			if (bizPerformanceManagementDO.getExpenditureProgress() == "null"){
				bizPerformanceManagementDO.setExpenditureProgress("0");
			}
			//按序处理申请数据
			//int i = Integer.parseInt(bizPerformanceManagementDO.getExpenditureProgress());
			//switch (i/25){
			BizPerformanceManagementVO bizFinancial1 = new BizPerformanceManagementVO();
			
			//总体目标
			Example exampleOver = new Example(OverallObjectiveDO.class);
			Criteria criteriaOver = exampleOver.createCriteria();
			criteriaOver.andEqualTo("budgetId", id);
			List<OverallObjectiveDO>  overList =  overallObjectiveDao.selectByExample(exampleOver);
			List<OverallObjectiveVO> overallObjectiveList=new ArrayList<>();
			
			if(overList!=null) {
				for(int i=0;i<overList.size();i++) {
					OverallObjectiveVO overallObjectiveVO=new OverallObjectiveVO();
					overallObjectiveVO.setId(isNull(overList.get(i).getId()+""));
					overallObjectiveVO.setTargetContent(isNull(overList.get(i).getTargetContent()+""));
					overallObjectiveList.add(overallObjectiveVO);
					bizFinancial1.setOverallObjective(overallObjectiveList);
				}
			}
			
			//产出指标
			Example example = new Example(OutPutIndexDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("budgetId", id);
			List<OutPutIndexDO>  outputIndex  =  outPutIndexDao.selectByExample(example);
			List<OutPutIndexQueryVO> outputIndexList=new ArrayList<>();
			
			if(outputIndex!=null) {
				for(int i=0;i<outputIndex.size();i++) {
					OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
					outputindexDo.setId(isNull(outputIndex.get(i).getId()+""));
					outputindexDo.setAnnualIndexValue(isNull(outputIndex.get(i).getAnnualIndexValue()+""));
					outputindexDo.setIndexContent(isNull(outputIndex.get(i).getIndexContent()+""));
					outputindexDo.setMediumTermIndexValue(isNull(outputIndex.get(i).getMediumTermIndexValue()+""));;
					outputindexDo.setTwoClassIndex(isNull(outputIndex.get(i).getTwoClassIndex()+""));

					outputindexDo.setThreeClassIndex(isNull(outputIndex.get(i).getThreeClassIndex()+""));
					outputindexDo.setIndexProperties(isNull(outputIndex.get(i).getIndexProperties()+""));
					outputindexDo.setIndexValue(isNull(outputIndex.get(i).getIndexValue()+""));
					outputindexDo.setUnitMeasure(isNull(outputIndex.get(i).getUnitMeasure()+""));
					outputIndexList.add(outputindexDo);
					bizFinancial1.setOutputIndex(outputIndexList);
				}
			}
			
			//效益指标
			Example example1 = new Example(BenefitIndexDO.class);
			Criteria criteria1 = example1.createCriteria();
			criteria1.andEqualTo("budgetId", id);
			List<BenefitIndexDO>  benefitIndex  =  benefitIndexDao.selectByExample(example1);
			List<OutPutIndexQueryVO> benefitIndexList=new ArrayList<>();
			if(benefitIndex!=null) {
				for(int i=0;i<benefitIndex.size();i++) {
					OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
					outputindexDo.setId(isNull(benefitIndex.get(i).getId()+""));
					outputindexDo.setAnnualIndexValue(isNull(benefitIndex.get(i).getAnnualIndexValue()+""));
					outputindexDo.setIndexContent(isNull(benefitIndex.get(i).getIndexContent()+""));
					outputindexDo.setMediumTermIndexValue(isNull(benefitIndex.get(i).getMediumTermIndexValue()+""));;
					outputindexDo.setTwoClassIndex(isNull(benefitIndex.get(i).getTwoClassIndex()+""));
					
					outputindexDo.setThreeClassIndex(isNull(benefitIndex.get(i).getThreeClassIndex()+""));
					outputindexDo.setIndexProperties(isNull(benefitIndex.get(i).getIndexProperties()+""));
					outputindexDo.setIndexValue(isNull(benefitIndex.get(i).getIndexValue()+""));
					outputindexDo.setUnitMeasure(isNull(benefitIndex.get(i).getUnitMeasure()+""));
					benefitIndexList.add(outputindexDo);
					bizFinancial1.setBenefitIndex(benefitIndexList);
				}
			}

			//满意度指标  satisfactionIndex
			Example exampleSatisfaction = new Example(SatisfactionIndexDO.class);
			Criteria criteriaSatisfaction = exampleSatisfaction.createCriteria();
			criteriaSatisfaction.andEqualTo("budgetId", id);
			List<SatisfactionIndexDO>  satisfactionIndex  =  satisfactionIndexDao.selectByExample(exampleSatisfaction);
			List<OutPutIndexQueryVO> satisfactionIndexList = new ArrayList<>();
			if(satisfactionIndex !=null && satisfactionIndex.size() > 0) {
				for(int i=0;i<satisfactionIndex.size();i++) {
					OutPutIndexQueryVO outputindexDo=new OutPutIndexQueryVO();
					outputindexDo.setId(isNull(satisfactionIndex.get(i).getId()+""));
					outputindexDo.setAnnualIndexValue(isNull(satisfactionIndex.get(i).getAnnualIndexValue()+""));
					outputindexDo.setIndexContent(isNull(satisfactionIndex.get(i).getIndexContent()+""));
					outputindexDo.setMediumTermIndexValue(isNull(satisfactionIndex.get(i).getMediumTermIndexValue()+""));;
					outputindexDo.setTwoClassIndex(isNull(satisfactionIndex.get(i).getTwoClassIndex()+""));
					
					outputindexDo.setThreeClassIndex(isNull(satisfactionIndex.get(i).getThreeClassIndex()+""));
					outputindexDo.setIndexProperties(isNull(satisfactionIndex.get(i).getIndexProperties()+""));
					outputindexDo.setIndexValue(isNull(satisfactionIndex.get(i).getIndexValue()+""));
					outputindexDo.setUnitMeasure(isNull(satisfactionIndex.get(i).getUnitMeasure()+""));
					satisfactionIndexList.add(outputindexDo);
					bizFinancial1.setSatisfactionIndex(satisfactionIndexList);
				}
			}
			
			switch (season){
				case 1:
					bizFinancial=  LsBeanUtils.copyProperties(bizPerformanceManagementDO,BizPerformanceManagementVO.class);
					bizFinancial.setOverallObjective(bizFinancial1.getOverallObjective());
					bizFinancial.setOutputIndex(bizFinancial1.getOutputIndex());
					bizFinancial.setBenefitIndex(bizFinancial1.getBenefitIndex());
					bizFinancial.setSatisfactionIndex(bizFinancial1.getSatisfactionIndex());
					bizPerformanceManagementVOs.add(bizFinancial);
					BizPerformanceManagementVO biz = new BizPerformanceManagementVO();
					bizPerformanceManagementVOs.add(biz);
					bizPerformanceManagementVOs.add(biz);
					bizPerformanceManagementVOs.add(biz);
					break;
				case 2:
					BizPerformanceManagementVO biz2 = new BizPerformanceManagementVO();
					bizPerformanceManagementVOs.add(biz2);
					bizFinancial=  LsBeanUtils.copyProperties(bizPerformanceManagementDO,BizPerformanceManagementVO.class);
					bizFinancial.setOverallObjective(bizFinancial1.getOverallObjective());
					bizFinancial.setOutputIndex(bizFinancial1.getOutputIndex());
					bizFinancial.setBenefitIndex(bizFinancial1.getBenefitIndex());
					bizFinancial.setSatisfactionIndex(bizFinancial1.getSatisfactionIndex());
					bizPerformanceManagementVOs.add(bizFinancial);
					bizPerformanceManagementVOs.add(biz2);
					bizPerformanceManagementVOs.add(biz2);
					break;
				case 3:
					BizPerformanceManagementVO biz3 = new BizPerformanceManagementVO();
					bizPerformanceManagementVOs.add(biz3);
					bizPerformanceManagementVOs.add(biz3);
					bizFinancial=  LsBeanUtils.copyProperties(bizPerformanceManagementDO,BizPerformanceManagementVO.class);
					bizFinancial.setOverallObjective(bizFinancial1.getOverallObjective());
					bizFinancial.setOutputIndex(bizFinancial1.getOutputIndex());
					bizFinancial.setBenefitIndex(bizFinancial1.getBenefitIndex());
					bizFinancial.setSatisfactionIndex(bizFinancial1.getSatisfactionIndex());
					bizPerformanceManagementVOs.add(bizFinancial);
					bizPerformanceManagementVOs.add(biz3);
					break;
				case 4:
					BizPerformanceManagementVO biz4 = new BizPerformanceManagementVO();
					bizPerformanceManagementVOs.add(biz4);
					bizPerformanceManagementVOs.add(biz4);
					bizPerformanceManagementVOs.add(biz4);
					bizFinancial=  LsBeanUtils.copyProperties(bizPerformanceManagementDO,BizPerformanceManagementVO.class);
					bizFinancial.setOverallObjective(bizFinancial1.getOverallObjective());
					bizFinancial.setOutputIndex(bizFinancial1.getOutputIndex());
					bizFinancial.setBenefitIndex(bizFinancial1.getBenefitIndex());
					bizFinancial.setSatisfactionIndex(bizFinancial1.getSatisfactionIndex());
					bizPerformanceManagementVOs.add(bizFinancial);
					break;
				default:
					break;
			}
		}
		return bizPerformanceManagementVOs;
	}


}
